;==============================================================
; WLA-DX banking setup
;==============================================================
.memorymap
defaultslot 0
slotsize $8000
slot 0 $0000
.endme

.rombankmap
bankstotal 1
banksize $8000
banks 1
.endro

;==============================================================
; SDSC tag and SMS rom header
;==============================================================
.sdsctag 1.2,"Simple Sample Playback","Simple sample playback","little-scale"

.bank 0 slot 0
.org $0000
;==============================================================
; Boot section
;==============================================================
    di              ; disable interrupts
    im 1            ; Interrupt mode 1
    jp main         ; jump to main program

.org $0066
;==============================================================
; Pause button handler
;==============================================================
    ; Do nothing
    retn



;==============================================================
; Main program
;==============================================================

main:

    ; Set up VDP registers
    
    ld hl,VdpData
    ld b,VdpDataEnd-VdpData
    ld c,$bf
    otir

    
    ; Clear VRAM
    
    ; 1. Set VRAM write address to 0 by outputting $4000 ORed with $0000
    ld a,$00
    out ($bf),a
    ld a,$40
    out ($bf),a
    ; 2. Output 16KB of zeroes
    ld bc, $4000    ; Counter for 16KB of VRAM
    ld a,$00        ; Value to write
    ClearVRAMLoop:
        out ($be),a ; Output to VRAM address, which is auto-incremented after each write
        dec c
        jp nz,ClearVRAMLoop
        dec b
        jp nz,ClearVRAMLoop
        
        ;==============================================================
    ; Load palette
    ;==============================================================
    ; 1. Set VRAM write address to CRAM (palette) address 0 (for palette index 0)
    ; by outputting $c000 ORed with $0000
    ld a,$00
    out ($bf),a
    ld a,$c0
    out ($bf),a
    ; 2. Output colour data
    ld hl,PaletteData
    ld b,(PaletteDataEnd-PaletteData)
    ld c,$be
    otir

    ;==============================================================
    ; Load tiles (font)
    ;==============================================================
    ; 1. Set VRAM write address to tile index 0
    ; by outputting $4000 ORed with $0000
    ld a,$00
    out ($bf),a
    ld a,$40
    out ($bf),a
    ; 2. Output tile data
    ld hl,FontData              ; Location of tile data
    ld bc,FontDataEnd-FontData  ; Counter for number of bytes to write
    WriteTilesLoop:
        ; Output data byte then three zeroes, because our tile data is 1 bit
        ; and must be increased to 4 bit
        ld a,(hl)        ; Get data byte
        out ($be),a
        inc hl           ; Add one to hl so it points to the next data byte
        dec bc
        ld a,b
        or c
        jp nz,WriteTilesLoop
        


    ;==============================================================
    ; Write text to name table
    ;==============================================================
    ; 1. Set VRAM write address to name table index 0
    ; by outputting $4000 ORed with $3800+0
    ld a,$00
    out ($bf),a
    ld a,$38|$40
    out ($bf),a
    ; 2. Output tilemap data
    ld hl,Message
    ld bc,MessageEnd-Message  ; Counter for number of bytes to write
    WriteTextLoop:
        ld a,(hl)    ; Get data byte
        out ($be),a
        inc hl       ; Point to next letter
        dec bc
        ld a,b
        or c
        jp nz,WriteTextLoop

    ; Turn screen on
    ld a,%11000000
;          |||| |`- Zoomed sprites -> 16x16 pixels
;          |||| `-- Doubled sprites -> 2 tiles per sprite, 8x16
;          |||`---- 30 row/240 line mode
;          ||`----- 28 row/224 line mode
;          |`------ VBlank interrupts
;          `------- Enable display
    out ($bf),a
    ld a,$81
    out ($bf),a




    ld a,$00
    out ($bf),a
    ld a,$40
    out ($bf),a
    ld a,%10000000
    out ($7f),a
    ld a,%00000000
    out ($7f),a
    ld a,%10100000
    out ($7f),a
    ld a,%00000000
    out ($7f),a
    ld a,%11000000
    out ($7f),a
    ld a,%00000000
    out ($7f),a
    
    ld a,$00
    out ($bf),a
    ld a,$00
    out ($bf),a
    ld a,$c4       ; Turn on the screen
    out ($bf),a
    ld a,$81
    out ($bf),a
    ld a,$00
    out ($bf),a
    ld a,$c0
    out ($bf),a


    ld a,$00
    ld ($c000),a
    
    ld hl,Sample_01
    ld a,l
    ld ($c100),a
    ld a,h
    ld ($c101),a

    ld hl,Sample_01End-Sample_01
    ld a,l
    ld ($c102),a
    ld a,h
    ld ($c103),a

    ld hl,Sample_02
    ld a,l
    ld ($c104),a
    ld a,h
    ld ($c105),a

    ld hl,Sample_02End-Sample_02
    ld a,l
    ld ($c106),a
    ld a,h
    ld ($c107),a

    ld hl,Sample_03
    ld a,l
    ld ($c108),a
    ld a,h
    ld ($c109),a

    ld hl,Sample_03End-Sample_03
    ld a,l
    ld ($c10a),a
    ld a,h
    ld ($c10b),a

    ld hl,Sample_04
    ld a,l
    ld ($c10c),a
    ld a,h
    ld ($c10d),a

    ld hl,Sample_04End-Sample_04
    ld a,l
    ld ($c10e),a
    ld a,h
    ld ($c10f),a

    ld hl,Sample_05
    ld a,l
    ld ($c110),a
    ld a,h
    ld ($c111),a

    ld hl,Sample_05End-Sample_05
    ld a,l
    ld ($c112),a
    ld a,h
    ld ($c113),a

    ld hl,Sample_06
    ld a,l
    ld ($c114),a
    ld a,h
    ld ($c115),a

    ld hl,Sample_06End-Sample_06
    ld a,l
    ld ($c116),a
    ld a,h
    ld ($c117),a

    ld hl,Sample_07
    ld a,l
    ld ($c118),a
    ld a,h
    ld ($c119),a

    ld hl,Sample_07End-Sample_07
    ld a,l
    ld ($c11a),a
    ld a,h
    ld ($c11b),a

    ld hl,Sample_08
    ld a,l
    ld ($c11c),a
    ld a,h
    ld ($c11d),a

    ld hl,Sample_08End-Sample_08
    ld a,l
    ld ($c11e),a
    ld a,h
    ld ($c11f),a
    
    ld hl,Sample_09
    ld a,l
    ld ($c120),a
    ld a,h
    ld ($c121),a

    ld hl,Sample_09End-Sample_09
    ld a,l
    ld ($c122),a
    ld a,h
    ld ($c123),a

    ld hl,Sample_10
    ld a,l
    ld ($c124),a
    ld a,h
    ld ($c125),a

    ld hl,Sample_10End-Sample_10
    ld a,l
    ld ($c126),a
    ld a,h
    ld ($c127),a

    ld hl,Sample_11
    ld a,l
    ld ($c128),a
    ld a,h
    ld ($c129),a

    ld hl,Sample_11End-Sample_11
    ld a,l
    ld ($c12a),a
    ld a,h
    ld ($c12b),a

    ld hl,Sample_12
    ld a,l
    ld ($c12c),a
    ld a,h
    ld ($c12d),a

    ld hl,Sample_12End-Sample_12
    ld a,l
    ld ($c12e),a
    ld a,h
    ld ($c12f),a

    ld hl,Sample_13
    ld a,l
    ld ($c130),a
    ld a,h
    ld ($c131),a

    ld hl,Sample_13End-Sample_13
    ld a,l
    ld ($c132),a
    ld a,h
    ld ($c133),a

    ld hl,Sample_14
    ld a,l
    ld ($c134),a
    ld a,h
    ld ($c135),a

    ld hl,Sample_14End-Sample_14
    ld a,l
    ld ($c136),a
    ld a,h
    ld ($c137),a

    ld hl,Sample_15
    ld a,l
    ld ($c138),a
    ld a,h
    ld ($c139),a

    ld hl,Sample_15End-Sample_15
    ld a,l
    ld ($c13a),a
    ld a,h
    ld ($c13b),a

    ld hl,Sample_16
    ld a,l
    ld ($c13c),a
    ld a,h
    ld ($c13d),a

    ld hl,Sample_16End-Sample_16
    ld a,l
    ld ($c13e),a
    ld a,h
    ld ($c13f),a
    
    
    
    
    
    ld hl,Sample_17
    ld a,l
    ld ($c140),a
    ld a,h
    ld ($c141),a

    ld hl,Sample_17End-Sample_17
    ld a,l
    ld ($c142),a
    ld a,h
    ld ($c143),a

    ld hl,Sample_18
    ld a,l
    ld ($c144),a
    ld a,h
    ld ($c145),a

    ld hl,Sample_18End-Sample_18
    ld a,l
    ld ($c146),a
    ld a,h
    ld ($c147),a

    ld hl,Sample_19
    ld a,l
    ld ($c148),a
    ld a,h
    ld ($c149),a

    ld hl,Sample_19End-Sample_19
    ld a,l
    ld ($c14a),a
    ld a,h
    ld ($c14b),a

    ld hl,Sample_20
    ld a,l
    ld ($c14c),a
    ld a,h
    ld ($c14d),a

    ld hl,Sample_20End-Sample_20
    ld a,l
    ld ($c14e),a
    ld a,h
    ld ($c14f),a

    ld hl,Sample_21
    ld a,l
    ld ($c150),a
    ld a,h
    ld ($c151),a

    ld hl,Sample_21End-Sample_21
    ld a,l
    ld ($c152),a
    ld a,h
    ld ($c153),a

    ld hl,Sample_22
    ld a,l
    ld ($c154),a
    ld a,h
    ld ($c155),a

    ld hl,Sample_22End-Sample_22
    ld a,l
    ld ($c156),a
    ld a,h
    ld ($c157),a

    ld hl,Sample_23
    ld a,l
    ld ($c158),a
    ld a,h
    ld ($c159),a

    ld hl,Sample_23End-Sample_23
    ld a,l
    ld ($c15a),a
    ld a,h
    ld ($c15b),a

    ld hl,Sample_24
    ld a,l
    ld ($c15c),a
    ld a,h
    ld ($c15d),a

    ld hl,Sample_24End-Sample_24
    ld a,l
    ld ($c15e),a
    ld a,h
    ld ($c15f),a
    
    ld hl,Sample_25
    ld a,l
    ld ($c160),a
    ld a,h
    ld ($c161),a

    ld hl,Sample_25End-Sample_25
    ld a,l
    ld ($c162),a
    ld a,h
    ld ($c163),a

    ld hl,Sample_26
    ld a,l
    ld ($c164),a
    ld a,h
    ld ($c165),a

    ld hl,Sample_26End-Sample_26
    ld a,l
    ld ($c166),a
    ld a,h
    ld ($c167),a

    ld hl,Sample_27
    ld a,l
    ld ($c168),a
    ld a,h
    ld ($c169),a

    ld hl,Sample_27End-Sample_27
    ld a,l
    ld ($c16a),a
    ld a,h
    ld ($c16b),a

    ld hl,Sample_28
    ld a,l
    ld ($c16c),a
    ld a,h
    ld ($c16d),a

    ld hl,Sample_28End-Sample_28
    ld a,l
    ld ($c16e),a
    ld a,h
    ld ($c16f),a

    ld hl,Sample_29
    ld a,l
    ld ($c170),a
    ld a,h
    ld ($c171),a

    ld hl,Sample_29End-Sample_29
    ld a,l
    ld ($c172),a
    ld a,h
    ld ($c173),a

    ld hl,Sample_30
    ld a,l
    ld ($c174),a
    ld a,h
    ld ($c175),a

    ld hl,Sample_30End-Sample_30
    ld a,l
    ld ($c176),a
    ld a,h
    ld ($c177),a

    ld hl,Sample_31
    ld a,l
    ld ($c178),a
    ld a,h
    ld ($c179),a

    ld hl,Sample_31End-Sample_31
    ld a,l
    ld ($c17a),a
    ld a,h
    ld ($c17b),a

    ld hl,Sample_32
    ld a,l
    ld ($c17c),a
    ld a,h
    ld ($c17d),a

    ld hl,Sample_32End-Sample_32
    ld a,l
    ld ($c17e),a
    ld a,h
    ld ($c17f),a



Check_Buttons:
    in a,($dc)
    ld hl,$c001
    cp (hl)
    ld ($c001),a
    jp z,Check_Buttons

    bit 4,a
    jp z,Button_1


    bit 5,a
    jp z,Button_2
    bit 0,a
    jp z,Up_Trg
    bit 1,a
    jp z,Down_Trg
    bit 2,a
    jp z,Left_Trg
    bit 3,a
    jp z,Right_Trg


   jp Check_Buttons
   
Button_1:
          bit 0,a
          jp z,Button_1_Up
          
          bit 1,a
          jp z,Button_1_Down
          
          bit 2,a
          jp z,Button_1_Left

          bit 3,a
          jp z,Button_1_Right

          jp Check_Buttons
          


Button_1_Up:
            ld a,($c000)
            inc a
            and %00111111
            ld ($c000),a
            ld a,($c001)

            ld a,44
            out ($bf),a
            ld a,$38|$41
            out ($bf),a
            ld a,($c000)
            and %11110000
            sra a
            sra a
            sra a
            sra a
            or %00010000
            out ($be),a
            ld a,0
            out ($be),a
            ld a,($c000)
            and %00001111
            or %00010000
            out ($be),a
            ld a,0
            out ($be),a
            jp Check_Buttons

Button_1_Down:
            ld a,($c000)
            dec a
            and %00111111
            ld ($c000),a
            ld a,($c001)

            ld a,44
            out ($bf),a
            ld a,$38|$41
            out ($bf),a
            ld a,($c000)
            and %11110000
            sra a
            sra a
            sra a
            sra a
            or %00010000
            out ($be),a
            ld a,0
            out ($be),a
            ld a,($c000)
            and %00001111
            or %00010000
            out ($be),a
            ld a,0
            out ($be),a
            jp Check_Buttons

Button_1_Left:
            ld a,($c002)
            dec a
            and $07
            ld ($c002),a
            ld a,($c001)

            ld a,108
            out ($bf),a
            ld a,$38|$41
            out ($bf),a
            ld a,($c002)
            and %11110000
            sra a
            sra a
            sra a
            sra a
            or %00010000
            out ($be),a
            ld a,0
            out ($be),a
            ld a,($c002)
            and %00001111
            or %00010000
            out ($be),a
            ld a,0
            out ($be),a
            jp Check_Buttons

Button_1_Right:
            ld a,($c002)
            inc a
            and $07
            ld ($c002),a
            ld a,($c001)

            ld a,108
            out ($bf),a
            ld a,$38|$41
            out ($bf),a
            ld a,($c002)
            and %11110000
            sra a
            sra a
            sra a
            sra a
            or %00010000
            out ($be),a
            ld a,0
            out ($be),a
            ld a,($c002)
            and %00001111
            or %00010000
            out ($be),a
            ld a,0
            out ($be),a
            jp Check_Buttons

Button_2:
          jp Check_Buttons


Up_Trg: 
        ld a,1
        ld ($c003),a
        jp Sample_Play

Down_Trg:
        ld a,2
        ld ($c003),a
        jp Sample_Play

Left_Trg:
        ld a,3
        ld ($c003),a
        jp Sample_Play

Right_Trg:
        ld a,4
        ld ($c003),a
        jp Sample_Play


Sample_Play:
    ld a,($c002)
    inc a
    ld b,a
    ld a,1
Sample_Play_LS:
                  inc a
                  inc a
                  inc a
                  inc a
                  djnz Sample_Play_LS
                  dec a
                  dec a
                  dec a
                  dec a
                  dec a
                  ld b,a
                  ld a,($c003)
                  add a,b
                  dec a


                  ld ($c003),a
                  sla a
                  sla a
                  ld h,$c1
                  ld l,a
                  ld a,(hl)
                  ld ($c004),a

                  ld a,($c003)
                  sla a
                  sla a
                  inc a
                  ld h,$c1
                  ld l,a
                  ld a,(hl)
                  ld ($c005),a

                  ld a,($c003)
                  sla a
                  sla a
                  inc a
                  inc a
                  ld h,$c1
                  ld l,a
                  ld a,(hl)
                  ld ($c006),a

                  ld a,($c003)
                  sla a
                  sla a
                  inc a
                  inc a
                  inc a
                  ld h,$c1
                  ld l,a
                  ld a,(hl)
                  ld ($c007),a
                  
                  ld a,($c004)
                  ld l,a
                  ld a,($c005)
                  ld h,a
                  ld a,($c006)
                  ld c,a
                  ld a,($c007)
                  ld b,a



    

    WriteSampleLoop:
        ld a,(hl)        ; Get data byte
        or %10010000
        out ($7f),a
        
        ld a,(hl)        ; Get data byte
        or %10110000
        out ($7f),a

        ld a,(hl)        ; Get data byte
        or %11010000
        out ($7f),a
        
            ld a,$00
    out ($bf),a
    ld a,$c0
    out ($bf),a


    ld a,(hl)
        out ($be),a
        xor $ff
        out ($be),a

        ld a,($c000)
        inc a
SR:
        dec a
        jp nz,SR



        inc hl           ; Add one to hl so it points to the next data byte
        dec bc
        ld a,b
        or c
        jp nz,WriteSampleLoop
        
        ld a,%10011111
        out ($7f),a
        
        ld a,%10111111
        out ($7f),a

        ld a,%11011111
        out ($7f),a

        jp Check_Buttons




    ; Infinite loop to stop program
Loop:


     jp Check_Buttons

;==============================================================
; Data
;==============================================================


Sample_01:
.db 8, 9, 10, 10, 11, 11, 12, 12, 12, 12, 12, 12, 11, 11, 11, 12, 10, 5, 3, 1, 6, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 8, 14, 11, 13, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 11, 12, 10, 7, 5, 7, 8, 11, 12, 9, 7, 3, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 3, 3, 3, 3, 7, 10, 12, 12, 11, 7, 6, 4, 10, 9, 11, 12, 11, 10, 7, 6, 6, 11, 13, 12, 12, 11, 10, 12, 14, 14, 14, 14, 14, 14, 14, 13, 13, 13, 14, 14, 14, 13, 11, 10, 8, 9, 10, 11, 8, 5, 4, 4, 6, 5, 7, 11, 12, 13, 13, 13, 14, 14, 14, 14, 14, 13, 12, 11, 10, 9, 8, 9, 8, 9, 8, 5, 3, 1, 0, 0, 0, 0, 1, 1, 3, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 1, 2, 2, 2, 3, 3, 2, 2, 2, 2, 1, 1, 0, 0, 1, 2, 2, 4, 6, 6, 5, 4, 2, 2, 6, 8, 8, 10, 10, 11, 11, 11, 12, 12, 13, 14, 13, 12, 12, 14, 14, 14, 14, 14, 14, 14, 14, 14, 13, 12, 13, 12, 12, 12, 11, 10, 10, 10, 9, 9, 8, 8, 8, 8, 10, 10, 11, 11, 11, 10, 10, 10, 10, 9, 9, 7, 5, 4, 4, 4, 5, 5, 5, 4, 3, 2, 1, 0, 0, 0, 1, 1, 1, 1, 1, 1, 2, 4, 6, 7, 6, 5, 4, 4, 5, 5, 4, 4, 3, 3, 3, 3, 3, 3, 4, 4, 5, 4, 4, 4, 6, 8, 11, 12, 13, 13, 13, 13, 13, 13, 14, 13, 12, 12, 11, 10, 10, 11, 11, 11, 12, 11, 11, 11, 11, 11, 11, 11, 11, 11, 10, 9, 7, 6, 6, 6, 5, 6, 5, 4, 4, 5, 5, 5, 6, 6, 7, 8, 8, 8, 9, 9, 8, 6, 6, 6, 5, 5, 4, 4, 4, 4, 5, 5, 6, 7, 6, 6, 5, 5, 4, 4, 4, 5, 5, 5, 6, 6, 5, 6, 5, 4, 3, 3, 3, 4, 5, 6, 7, 7, 8, 8, 8, 9, 10, 10, 10, 10, 10, 10, 10, 10, 11, 11, 10, 10, 9, 8, 7, 5, 4, 3, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 3, 4, 5, 7, 8, 9, 10, 10, 11, 11, 12, 11, 11, 11, 11, 11, 11, 11, 11, 11, 11, 11, 11, 11, 11, 10, 9, 8, 8, 8, 8, 7, 6, 5, 5, 5, 5, 5, 5, 5, 5, 5, 4, 4, 4, 4, 5, 5, 5, 6, 6, 6, 6, 5, 6, 6, 6, 7, 7, 8, 8, 8, 9, 9, 10, 11, 11, 12, 12, 12, 12, 11, 10, 9, 8, 8, 7, 6, 6, 6, 5, 5, 5, 5, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 5, 4, 3, 3, 3, 3, 3, 4, 4, 4, 5, 5, 5, 6, 7, 7, 8, 8, 8, 8, 8, 9, 9, 9, 9, 8, 8, 8, 8, 8, 8, 8, 8, 7, 7, 7, 7, 7, 7, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 7, 7, 8, 8, 8, 8, 7, 7, 6, 6, 6, 6, 7, 7, 7, 7, 6, 6, 6, 6, 7, 8, 9, 9, 9, 9, 9, 9, 9, 8, 8, 7, 6, 6, 5, 5, 5, 5, 5, 5, 6, 6, 6, 7, 7, 8, 8, 8, 8, 8, 9, 9, 9, 9, 9, 8, 8, 8, 8, 7, 7, 7, 6, 6, 6, 5, 5, 5, 5, 4, 4, 4, 4, 4, 5, 5, 6, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 8, 8, 8, 8, 9, 9, 9, 9, 9, 9, 8, 8, 8, 8, 8, 8, 8, 7, 7, 7, 6, 6, 6, 6, 6, 6, 6, 6, 6, 5, 6, 6, 6, 7, 7, 7, 7, 7, 8, 8, 9, 9, 9, 9, 9, 9, 9, 9, 8, 8, 8, 7, 7, 6, 6, 6, 6, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 6, 6, 6, 6, 6, 6, 6, 7, 7, 7, 7, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 7, 7, 7, 7, 7, 6, 6, 6, 6, 6, 5, 5, 6, 6, 6, 6, 6, 6, 6, 6, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 8, 8, 8, 8, 8, 8, 7, 7, 7, 7, 6, 6, 6, 6, 6, 6, 6, 6, 5, 6, 6, 6, 6, 6, 7, 7, 7, 8, 8, 8, 8, 9, 9, 9, 9, 9, 9, 9, 9, 9, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 7, 7, 7, 7, 6, 6, 6, 6, 6, 6, 6, 5, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 6, 6, 6, 6, 6, 7, 7, 7, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 7, 7, 7, 7, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 7, 7, 7, 7, 7, 7, 6, 6, 6, 6, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 7, 7, 7, 7, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 7, 7, 7, 7, 8, 8, 8, 8, 8, 8, 8, 8
Sample_01End:

Sample_02:
.db 14, 14, 14, 14, 14, 7, 7, 4, 1, 2, 1, 12, 9, 4, 0, 0, 7, 8, 2, 1, 0, 0, 0, 0, 0, 0, 7, 13, 14, 14, 8, 14, 12, 14, 9, 10, 14, 14, 12, 8, 8, 10, 11, 1, 0, 0, 0, 0, 0, 0, 0, 6, 6, 9, 12, 12, 9, 3, 0, 7, 14, 14, 14, 13, 10, 10, 13, 8, 8, 9, 11, 2, 0, 0, 3, 9, 9, 6, 4, 1, 0, 0, 5, 5, 7, 10, 14, 8, 9, 7, 9, 11, 10, 10, 8, 7, 6, 0, 2, 1, 4, 2, 0, 1, 4, 8, 10, 7, 14, 9, 5, 1, 0, 2, 7, 8, 5, 6, 10, 9, 13, 10, 7, 7, 13, 14, 9, 10, 6, 7, 4, 7, 3, 3, 6, 1, 0, 6, 1, 5, 2, 3, 11, 12, 13, 14, 6, 12, 14, 14, 9, 2, 1, 0, 6, 9, 6, 12, 13, 11, 12, 12, 11, 11, 7, 5, 1, 1, 3, 4, 2, 1, 7, 14, 13, 12, 14, 11, 6, 2, 4, 2, 4, 12, 14, 10, 14, 8, 5, 5, 9, 5, 4, 5, 6, 2, 6, 4, 8, 4, 12, 6, 9, 9, 13, 11, 12, 10, 3, 5, 7, 11, 9, 2, 3, 1, 5, 2, 10, 12, 8, 5, 8, 11, 8, 10, 11, 5, 3, 6, 4, 9, 9, 10, 13, 14, 11, 9, 4, 4, 0, 2, 1, 5, 6, 2, 6, 5, 9, 7, 9, 8, 11, 7, 6, 4, 4, 8, 10, 9, 8, 12, 14, 10, 8, 10, 8, 8, 3, 3, 1, 2, 4, 6, 8, 5, 7, 7, 10, 7, 8, 7, 5, 8, 5, 7, 11, 7, 6, 7, 11, 6, 7, 9, 7, 8, 4, 4, 5, 3, 1, 4, 8, 4, 5, 6, 6, 8, 12, 11, 12, 9, 9, 7, 5, 8, 4, 7, 6, 4, 7, 6, 7, 8, 8, 7, 7, 6, 4, 4, 5, 5, 5, 4, 6, 8, 9, 10, 10, 9, 8, 10, 8, 7, 9, 6, 5, 5, 7, 5, 4, 4, 4, 6, 6, 5, 7, 9, 5, 8, 9, 8, 7, 10, 9, 8, 9, 6, 8, 6, 5, 11, 7, 5, 7, 5, 8, 6, 5, 5, 5, 8, 6, 9, 9, 8, 8, 8, 6, 7, 8, 7, 9, 9, 6, 6, 8, 8, 8, 7, 8, 9, 7, 7, 4, 5, 4, 6, 6, 8, 7, 8, 9, 9, 7, 8, 8, 8, 6, 7, 8, 7, 6, 7, 7, 7, 7, 6, 7, 7, 8, 10, 9, 10, 7, 6, 6, 6, 7, 7, 6, 6, 6, 7, 9, 8, 9, 9, 7, 6, 5, 6, 7, 7, 7, 7, 7, 6, 6, 6, 7, 8, 6, 7, 8, 10, 8, 7, 5, 5, 5, 5, 6, 6, 6, 7, 7, 8, 7, 7, 8, 9, 7, 7, 8, 8, 9, 8, 8, 8, 8, 9, 9, 8, 7, 5, 4, 4, 5, 6, 8, 8, 8, 5, 5, 5, 7, 6, 8, 7, 8, 9, 8, 7, 7, 8, 8, 7, 9, 7, 8, 8, 8, 7, 6, 5, 4, 5, 5, 6, 6, 6, 7, 8, 9, 9, 9, 8, 8, 6, 8, 9, 8, 8, 8, 8, 7, 7, 7, 6, 5, 7, 7, 7, 7, 6, 6, 6, 7, 8, 6, 6, 6, 7, 7, 7, 8, 9, 8, 8, 8, 8, 8, 7, 8, 8, 9, 8, 6, 4, 5, 4, 6, 6, 7, 7, 7, 7, 7, 8, 7, 7, 7, 7, 8, 7, 7, 7, 8, 7, 8, 8, 8, 7, 7, 7, 6, 6, 6, 6, 6, 7, 7, 6, 7, 7, 7, 7, 6, 7, 7, 8, 8, 8, 8, 7, 7, 7, 7, 8, 8, 8, 8, 7, 6, 6, 5, 6, 6, 6, 6, 7, 7, 6, 7, 7, 7, 7, 8, 8, 8, 8, 8, 8, 8, 8, 8, 7, 7, 7, 7, 7, 6, 6, 6, 6, 6, 6, 6, 7, 7, 7, 7, 8, 8, 8, 8, 8, 8, 8, 8, 8, 7, 7, 7, 6, 6, 6, 7
Sample_02End:

Sample_03:
.db 6, 5, 9, 6, 4, 9, 8, 10, 9, 7, 7, 9, 6, 6, 7, 8, 8, 8, 6, 6, 6, 6, 5, 6, 6, 7, 7, 7, 7, 6, 8, 6, 8, 7, 6, 7, 8, 6, 5, 5, 9, 8, 10, 6, 7, 9, 9, 9, 10, 6, 4, 10, 7, 6, 6, 6, 8, 6, 8, 8, 7, 12, 5, 9, 5, 6, 6, 5, 9, 6, 5, 9, 3, 7, 4, 5, 7, 10, 9, 7, 8, 8, 6, 9, 7, 6, 9, 11, 9, 9, 7, 10, 8, 7, 6, 7, 5, 5, 7, 5, 3, 12, 6, 6, 8, 8, 3, 6, 7, 7, 6, 8, 9, 7, 6, 8, 7, 4, 10, 9, 6, 9, 9, 10, 8, 5, 3, 5, 5, 3, 4, 6, 6, 8, 10, 8, 8, 7, 9, 6, 6, 5, 9, 6, 6, 7, 11, 5, 5, 10, 6, 6, 5, 9, 5, 4, 7, 6, 8, 7, 9, 7, 10, 7, 10, 7, 6, 4, 5, 4, 8, 9, 5, 7, 8, 7, 6, 7, 6, 6, 6, 8, 8, 6, 5, 9, 8, 7, 9, 9, 7, 6, 6, 7, 6, 8, 6, 6, 8, 6, 8, 7, 7, 6, 10, 8, 6, 8, 6, 6, 8, 9, 7, 9, 8, 7, 6, 9, 8, 6, 7, 5, 8, 6, 8, 7, 4, 9, 6, 6, 7, 5, 9, 6, 6, 8, 9, 8, 5, 8, 8, 8, 8, 8, 6, 6, 7, 5, 6, 9, 9, 7, 7, 7, 8, 8, 8, 8, 6, 10, 6, 9, 7, 8, 6, 5, 8, 6, 5, 9, 7, 8, 7, 5, 8, 6, 9, 6, 8, 5, 7, 9, 5, 6, 7, 8, 7, 6, 8, 8, 8, 5, 8, 9, 8, 8, 5, 6, 10, 9, 6, 7, 8, 5, 8, 9, 5, 5, 7, 9, 8, 9, 9, 8, 5, 5, 9, 7, 7, 7, 9, 8, 6, 6, 7, 7, 8, 5, 6, 8, 9, 7, 7, 6, 7, 8, 5, 7, 8, 8, 8, 7, 6, 8, 7, 6, 9, 7, 8, 8, 7, 7, 5, 8, 7, 6, 6, 8, 7, 5, 7, 9, 7, 5, 7, 7, 7, 7, 7, 5, 8, 8, 7, 8, 7, 8, 5, 6, 8, 6, 7, 7, 6, 7, 8, 8, 9, 7, 8, 6, 7, 6, 7, 6, 8, 7, 6, 6, 7, 7, 6, 7, 6, 7, 7, 8, 9, 6, 8, 9, 8, 7, 5, 6, 7, 7, 7, 5, 10, 7, 7, 6, 7, 6, 7, 8, 8, 6, 6, 8, 8, 8, 6, 6, 6, 9, 6, 9, 7, 7, 9, 7, 8, 8, 8, 8, 7, 6, 8, 6, 6, 7, 7, 8, 7, 6, 6, 8, 7, 6, 5, 8, 6, 8, 8, 10, 5, 7, 8, 7, 7, 7, 7, 8, 8, 7, 7, 7, 7, 7, 7, 7, 7, 5, 7, 6, 6, 7, 6, 6, 4, 7, 8, 7, 8, 8, 7, 8, 8, 7, 7, 7, 7, 7, 8, 6, 7, 6, 8, 7, 7, 6, 7, 7, 8, 8, 7, 7, 7, 7, 6, 6, 8, 7, 5, 8, 7, 7, 8, 8, 7, 7, 7, 7, 6, 8, 7, 7, 7, 7, 7, 8, 7, 7, 8, 6, 7, 6, 8, 7, 7, 6, 7, 8, 8, 7, 7, 7, 7, 6, 7, 7, 7, 7, 7, 8, 8, 7, 8, 8, 7, 8, 6, 6, 7, 7, 7, 8, 8, 6, 6, 7, 7, 7, 7, 7, 7, 6, 8, 8, 8, 8, 6, 7, 7, 7, 8, 6, 7, 8, 8, 7, 8, 7, 6, 6, 6, 6, 7, 7, 7, 7, 6, 6, 7, 7, 7, 7, 7, 8, 8, 6, 7, 7, 7, 8, 8, 8, 7, 7, 8, 8, 7, 7, 6, 6, 8, 7, 7, 7, 7, 7, 7, 7, 8, 6, 6, 7, 7, 7, 8, 7, 8, 7, 7, 7, 7, 7, 7, 7, 8, 8, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 6, 7, 7, 7, 7, 7, 7, 7, 7, 8, 6, 7, 6, 7, 7, 7, 7, 6, 7, 8, 8, 7, 7, 7, 8, 7, 8, 7, 7, 7, 7, 8, 7, 7, 8, 6, 6, 7, 7, 6, 7, 7, 6, 7, 7, 7, 7, 7, 7, 7, 7, 7, 8, 7, 6, 7, 7, 6, 7, 7, 7, 7, 7, 7, 7, 8, 7, 7, 7, 6, 7, 6, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 6, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 8, 7, 7, 8, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 6, 6, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 8
Sample_03End:

Sample_04:
.db 6, 4, 3, 3, 3, 4, 4, 4, 6, 3, 8, 10, 12, 10, 14, 14, 14, 13, 14, 13, 9, 6, 6, 4, 2, 0, 0, 0, 0, 0, 0, 0, 1, 1, 4, 7, 7, 7, 8, 12, 13, 12, 13, 12, 9, 12, 14, 10, 6, 7, 13, 10, 9, 13, 11, 11, 11, 13, 13, 13, 12, 10, 12, 9, 7, 5, 6, 4, 2, 0, 0, 0, 0, 0, 0, 0, 3, 3, 1, 3, 11, 12, 14, 14, 13, 14, 14, 14, 14, 14, 14, 14, 13, 10, 9, 8, 8, 9, 8, 7, 5, 6, 8, 8, 8, 7, 7, 2, 4, 3, 4, 3, 3, 3, 3, 1, 0, 0, 0, 0, 1, 2, 3, 6, 7, 10, 13, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 13, 11, 7, 6, 3, 4, 5, 3, 3, 2, 2, 3, 3, 3, 2, 3, 3, 4, 4, 3, 3, 3, 3, 3, 3, 4, 4, 7, 8, 8, 7, 8, 9, 10, 11, 12, 13, 14, 14, 14, 14, 14, 14, 14, 13, 12, 10, 7, 4, 3, 3, 2, 1, 0, 0, 0, 0, 0, 0, 0, 1, 2, 3, 4, 4, 5, 7, 8, 9, 9, 9, 9, 10, 10, 10, 10, 10, 11, 12, 12, 12, 12, 13, 13, 14, 14, 14, 14, 12, 10, 9, 7, 4, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 2, 3, 5, 7, 10, 12, 13, 13, 13, 13, 12, 12, 12, 11, 11, 11, 11, 12, 13, 13, 13, 13, 11, 10, 9, 6, 5, 4, 3, 3, 2, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 3, 5, 8, 11, 13, 13, 14, 14, 14, 14, 14, 14, 14, 14, 13, 13, 12, 12, 11, 9, 8, 7, 5, 4, 3, 3, 3, 3, 2, 2, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 1, 2, 3, 5, 6, 9, 11, 12, 13, 14, 14, 14, 14, 14, 14, 14, 14, 14, 13, 13, 13, 12, 9, 7, 5, 4, 3, 3, 2, 1, 1, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 2, 3, 4, 5, 5, 7, 9, 10, 11, 12, 13, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 13, 12, 11, 9, 7, 5, 4, 2, 1, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 2, 4, 6, 7, 8, 10, 11, 12, 13, 13, 13, 14, 13, 14, 14, 14, 14, 14, 14, 13, 13, 13, 11, 9, 6, 4, 3, 3, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 2, 4, 5, 7, 7, 7, 8, 10, 11, 12, 13, 13, 13, 14, 14, 14, 14, 14, 13, 13, 13, 12, 11, 10, 9, 7, 6, 4, 3, 2, 1, 1, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 2, 3, 5, 6, 7, 9, 9, 10, 12, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 12, 12, 12, 12, 11, 10, 7, 5, 4, 3, 2, 1, 1, 1, 1, 0, 0, 0, 0, 0, 1, 1, 1, 2, 3, 5, 6, 7, 8, 10, 12, 13, 14, 14, 14, 14, 14, 14, 14, 13, 13, 13, 13, 12, 11, 11, 10, 8, 6, 4, 3, 2, 2, 2, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 2, 2, 3, 4, 6, 7, 9, 10, 11, 13, 13, 13, 13, 13, 14, 14, 14, 14, 13, 13, 13, 13, 13, 11, 9, 7, 4, 3, 2, 2, 2, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 2, 3, 4, 4, 5, 7, 7, 8, 8, 9, 11, 12, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 12, 12, 11, 9, 8, 6, 4, 3, 2, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 12, 11, 9, 7, 5, 4, 3, 2, 2, 1, 1, 1, 0, 0, 0, 0, 0, 1, 1, 2, 3, 4, 5, 6, 8, 9, 11, 12, 13, 13, 14, 14, 13, 13, 13, 13, 13, 12, 12, 12, 12, 12, 11, 10, 9, 9, 7, 6, 4, 3, 2, 2, 2, 2, 1, 1, 0, 0, 0, 1, 1, 1, 2, 2, 3, 5, 7, 9, 10, 11, 12, 13, 13, 13, 14, 14, 14, 14, 14, 13, 13, 12, 12, 11, 10, 10, 9, 7, 6, 5, 4, 3, 3, 2, 2, 2, 2, 1, 1, 1, 1, 1, 2, 2, 2, 2, 3, 4, 5, 6, 7, 9, 10, 12, 12, 13, 13, 13, 14, 14, 14, 13, 13, 13, 13, 12, 11, 10, 8, 7, 6, 5, 4, 3, 3, 2, 1, 1, 1, 1, 1, 1, 2, 2, 2, 3, 3, 3, 3, 3, 4, 5, 6, 8, 9, 10, 11, 12, 12, 12, 12, 13, 13, 13, 13, 13, 13, 13, 13, 12, 11, 10, 8, 7, 6, 4, 3, 2, 1, 1, 1, 1, 1, 1, 1, 1, 2, 2, 3, 3, 4, 5, 5, 6, 7, 8, 9, 10, 11, 11, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 11, 11, 10, 9, 8, 6, 5, 4, 3, 2, 2, 2, 1, 1, 1, 2, 2, 2, 2, 2, 2, 3, 3, 4, 6, 8, 10, 11, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 11, 11, 11, 11, 10, 9, 8, 7, 6, 5, 5, 4, 4, 4, 3, 3, 2, 2, 2, 2, 2, 2, 2, 2, 3, 3, 4, 5, 6, 7, 8, 9, 10, 10, 11, 11, 12, 12, 12, 12, 12, 12, 12, 12, 12, 11, 10, 9, 9, 7, 6, 5, 5, 5, 4, 4, 3, 3, 2, 2, 2, 2
Sample_04End:

Sample_05:
.db 6, 2, 14, 10, 9, 1, 14, 0, 14, 0, 14, 0, 14, 7, 14, 4, 14, 0, 5, 0, 13, 11, 14, 13, 14, 0, 3, 0, 4, 0, 14, 14, 14, 13, 10, 0, 1, 0, 8, 7, 14, 12, 13, 5, 8, 1, 9, 5, 9, 2, 7, 2, 9, 11, 14, 13, 12, 3, 0, 0, 1, 3, 13, 14, 14, 12, 7, 0, 0, 0, 3, 8, 14, 14, 14, 8, 6, 1, 0, 1, 5, 5, 11, 11, 12, 10, 7, 4, 4, 2, 3, 4, 7, 9, 12, 12, 12, 7, 4, 1, 1, 2, 4, 10, 13, 13, 12, 9, 2, 1, 1, 3, 5, 9, 12, 13, 11, 10, 6, 3, 1, 2, 4, 7, 10, 13, 13, 11, 7, 3, 1, 1, 3, 6, 10, 13, 13, 12, 8, 3, 1, 2, 3, 7, 9, 12, 12, 11, 7, 5, 3, 4, 4, 5, 6, 9, 10, 11, 10, 8, 5, 2, 2, 3, 5, 8, 10, 12, 12, 8, 5, 3, 3, 3, 5, 8, 12, 11, 10, 8, 6, 3, 4, 4, 6, 7, 10, 10, 11, 8, 8, 5, 4, 3, 5, 6, 9, 10, 11, 8, 7, 5, 5, 4, 6, 7, 8, 10, 9, 9, 7, 6, 5, 6, 6, 7, 7, 8, 9, 8, 7, 7, 6, 6, 6, 6, 7, 7, 7, 8, 9, 8, 8, 6, 6, 5, 6, 7, 8, 9, 9, 8, 7, 6, 5, 5, 6, 6, 8, 9, 9, 8, 7, 6, 5, 6, 7, 7, 8, 8, 8, 7, 7, 6, 6, 6, 7, 7, 7, 8, 8, 8, 7, 7, 7, 7, 6, 6, 7, 7, 8, 8, 8, 7, 6, 6, 6, 6, 7, 8, 8, 9, 8, 7, 6, 6, 6, 6, 7, 8, 8, 8, 7, 7, 6, 7, 7, 7, 7, 7, 7, 7, 8, 8, 8, 7, 6, 6, 6, 6, 7, 8, 9, 8, 7, 6, 5, 5, 6, 7, 8, 9, 9, 8, 7, 6, 5, 6, 6, 7, 8, 8, 8, 8, 7, 6, 6, 6, 7, 7, 7, 8, 8, 8, 7, 7, 6, 6, 7, 6, 7, 7, 8, 8, 7, 7, 7, 7, 7, 7, 7, 7, 7, 8, 7, 7, 7, 6, 6, 6, 7, 7, 8, 7, 7, 7, 7, 6, 6, 7, 7, 7, 8, 7, 7, 7, 7, 6, 7, 7, 8, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 8, 7, 7, 7, 7, 6, 7, 7, 8, 8, 7
Sample_05End:

Sample_06:
.db 7, 7, 10, 10, 0, 7, 14, 0, 14, 9, 0, 14, 0, 14, 0, 14, 0, 11, 1, 12, 1, 14, 0, 14, 0, 14, 0, 14, 0, 14, 0, 9, 11, 0, 14, 0, 14, 0, 14, 0, 14, 5, 4, 13, 0, 14, 0, 13, 4, 5, 12, 0, 14, 0, 14, 0, 14, 0, 13, 5, 5, 12, 1, 13, 3, 11, 6, 6, 10, 4, 10, 5, 7, 11, 2, 14, 0, 14, 0, 14, 1, 11, 5, 6, 10, 2, 13, 0, 13, 2, 9, 8, 3, 13, 1, 14, 0, 14, 1, 9, 9, 2, 14, 0, 14, 0, 14, 0, 13, 2, 11, 4, 9, 4, 10, 4, 11, 3, 12, 1, 13, 1, 12, 2, 10, 5, 8, 5, 7, 6, 8, 6, 9, 5, 9, 5, 10, 4, 10, 5, 8, 8, 5, 9, 3, 12, 2, 13, 2, 12, 4, 9, 6, 6, 9, 4, 11, 4, 10, 5, 8, 8, 5, 8, 5, 8, 5, 7, 6, 7, 7, 7, 7, 6, 8, 4, 9, 5, 8, 6, 7, 8, 6, 8, 6, 8, 6, 7, 7, 7, 7, 7, 8, 7, 7, 8, 6, 8, 6, 8, 6, 7, 7, 6, 8, 6, 8, 7, 8, 6, 8, 6, 6, 8, 5, 9, 5, 9, 5, 9, 6, 7, 7, 6, 7, 7, 9, 5, 9, 5, 9, 5, 9, 6, 8, 6, 8, 5, 9, 5, 10, 5, 9, 6, 9, 6, 8, 7, 7, 8, 5, 8, 5, 9, 5, 9, 5, 9, 6, 8, 6, 8, 6, 8, 7, 8, 6, 9, 5, 9, 5, 9, 5, 10, 5, 9, 6, 8, 7, 7, 7, 6, 8, 6, 7, 6, 8, 6, 8, 6, 8, 6, 9, 5, 9, 5, 8, 6, 7, 6, 8, 7, 7, 7, 6, 8, 7, 7, 8, 6, 9, 6, 8, 6, 7, 7, 6, 8, 5, 9, 5, 9, 5, 9, 4, 9, 5, 8, 7, 7, 7, 7, 7, 7, 6, 8, 6, 8, 6, 8, 6, 8, 6, 8, 6, 8, 6, 7, 6, 7, 6, 8, 6, 8, 7, 7, 7, 7, 7, 7, 7, 6, 8, 6, 8, 7, 7, 8, 6, 8, 6, 7, 6, 8, 6, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 8, 6, 8, 6, 8, 6, 8, 6, 8, 6, 7, 6, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 6, 8, 6, 8, 6, 8, 6, 8, 6, 8, 6, 8, 6, 8, 6, 7, 7, 7, 7, 8, 6, 8, 6, 8, 6, 8, 6, 8, 7, 7, 7, 6, 8, 6, 8, 6, 8, 6, 8, 6, 8, 6, 8, 6, 8, 6, 8, 6, 8, 6, 8, 6, 8, 6, 8, 7, 7, 7, 6, 8, 6, 8, 6, 8, 6, 8, 6, 8, 6, 8, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 8, 6, 8, 6, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 8, 6, 8, 6, 7, 6, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 8, 6, 7, 7, 7, 7, 7, 7, 6, 8, 6, 8, 6, 8, 6, 8, 6, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 6, 7, 6, 8, 6, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 6, 8, 6, 8, 6, 8, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 6, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 6, 8, 6, 8, 6, 8, 6, 7
Sample_06End:

Sample_07:
.db 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 8, 7, 7, 7, 7, 7, 7, 8, 7, 8, 6, 6, 7, 6, 7, 7, 7, 7, 7, 7, 8, 6, 7, 8, 6, 8, 6, 7, 7, 7, 6, 6, 10, 8, 11, 4, 10, 6, 8, 7, 8, 2, 7, 6, 8, 4, 6, 10, 5, 7, 3, 6, 7, 10, 13, 8, 8, 5, 3, 5, 2, 8, 4, 6, 7, 8, 8, 7, 6, 8, 3, 7, 5, 13, 6, 9, 7, 3, 0, 2, 6, 6, 3, 7, 9, 3, 12, 5, 7, 2, 6, 4, 8, 12, 11, 3, 9, 5, 5, 8, 11, 6, 6, 4, 11, 9, 7, 5, 2, 0, 12, 7, 4, 12, 5, 5, 13, 5, 10, 7, 12, 7, 11, 3, 3, 2, 7, 5, 13, 9, 10, 7, 5, 8, 10, 5, 6, 9, 2, 6, 8, 7, 8, 7, 8, 2, 6, 6, 6, 12, 7, 4, 1, 10, 7, 2, 7, 11, 10, 10, 9, 3, 10, 4, 4, 10, 5, 7, 6, 3, 9, 10, 5, 6, 6, 1, 4, 7, 10, 8, 5, 6, 7, 7, 6, 7, 5, 10, 10, 5, 8, 0, 5, 8, 9, 11, 8, 10, 5, 3, 10, 6, 10, 7, 8, 9, 7, 9, 8, 6, 12, 2, 10, 8, 8, 6, 7, 5, 7, 7, 6, 6, 7, 4, 10, 6, 5, 7, 5, 10, 10, 6, 7, 6, 8, 7, 5, 8, 8, 8, 6, 8, 7, 8, 7, 8, 7, 7, 8, 7, 8, 6, 6, 5, 5, 6, 7, 6, 8, 7, 9, 7, 8, 5, 7, 7, 6, 6, 8, 7, 7, 6, 8, 7, 8, 8, 6, 8, 7, 7, 7, 7, 7, 7, 8, 7, 7, 7, 7, 7, 8, 6, 7, 7, 8, 7, 7, 7, 7, 7, 9, 6, 7, 7, 7, 8, 7, 9, 6, 7, 7, 7, 8, 7, 7, 6, 6, 8, 7, 7, 8, 7, 7, 7, 7, 6, 7, 8, 7, 8, 7, 7, 7, 6, 6, 8, 7, 7, 7, 7, 7, 6, 7, 7, 7, 7, 6, 7, 7, 7, 6, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 8, 8, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 8, 7, 7, 6, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 6, 7, 8, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 8, 6, 7, 7, 7, 7, 7, 6, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 6, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 8, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 6, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 8, 8, 6, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 8, 7, 7, 8, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 6, 7
Sample_07End:

Sample_08:
.db 8, 7, 8, 4, 7, 10, 8, 8, 7, 10, 3, 9, 9, 2, 0, 3, 10, 10, 7, 12, 11, 7, 7, 9, 2, 6, 12, 11, 9, 11, 9, 6, 2, 4, 7, 4, 11, 13, 10, 9, 6, 6, 5, 3, 5, 9, 10, 10, 7, 7, 5, 3, 4, 7, 7, 9, 12, 9, 7, 7, 4, 2, 4, 9, 7, 8, 12, 10, 3, 5, 5, 4, 3, 9, 11, 8, 9, 10, 6, 3, 5, 6, 5, 7, 10, 10, 5, 7, 7, 6, 4, 6, 10, 10, 6, 9, 9, 6, 4, 6, 8, 4, 8, 8, 5, 1, 7, 10, 4, 6, 9, 7, 4, 7, 11, 5, 5, 6, 10, 0, 5, 11, 6, 8, 9, 13, 7, 4, 7, 6, 4, 3, 7, 11, 5, 12, 12, 2, 2, 6, 8, 4, 11, 12, 11, 9, 5, 5, 2, 4, 9, 9, 11, 11, 12, 6, 4, 7, 5, 5, 4, 11, 13, 7, 6, 11, 3, 2, 8, 8, 7, 10, 13, 8, 2, 5, 8, 3, 6, 12, 10, 5, 10, 8, 4, 4, 9, 9, 7, 8, 11, 8, 4, 5, 7, 6, 4, 6, 9, 5, 6, 7, 8, 5, 9, 10, 9, 4, 9, 6, 5, 6, 8, 7, 7, 5, 8, 6, 3, 9, 8, 6, 8, 10, 8, 4, 6, 6, 5, 5, 10, 9, 9, 8, 8, 5, 4, 6, 8, 8, 8, 10, 10, 4, 3, 5, 5, 4, 8, 11, 9, 7, 9, 5, 2, 4, 8, 7, 7, 11, 12, 6, 5, 7, 5, 4, 7, 10, 8, 7, 10, 8, 2, 3, 6, 4, 5, 9, 11, 9, 7, 8, 7, 3, 4, 7, 7, 6, 11, 12, 8, 4, 7, 6, 3, 5, 11, 10, 8, 11, 10, 4, 4, 6, 5, 2, 8, 11, 9, 7, 9, 8, 3, 4, 7, 7, 6, 11, 10, 8, 6, 7, 5, 2, 4, 7, 8, 8, 10, 11, 8, 5, 5, 5, 3, 6, 9, 11, 8, 10, 10, 5, 2, 5, 5, 5, 9, 12, 10, 7, 7, 5, 2, 3, 8, 8, 8, 11, 11, 7, 4, 4, 4, 4, 7, 10, 10, 9, 8, 8, 5, 3, 6, 7, 7, 8, 11, 10, 6, 6, 6, 4, 4, 7, 8, 7, 8, 11, 8, 4, 6, 6, 4, 5, 10, 9, 8, 9, 9, 5, 4, 6, 6, 6, 8, 10, 9, 8, 7, 6, 4, 5, 6, 8, 8, 8, 10, 8, 6, 5, 7, 5, 4, 8, 9, 8, 8, 10, 7, 4, 6, 7, 5, 6, 10, 10, 7, 8, 9, 5, 4, 7, 7, 6, 8, 10, 8, 6, 7, 6, 5, 5, 7, 8, 8, 8, 9, 8, 6, 5, 6, 6, 6, 8, 10, 8, 7, 9, 6, 4, 5, 8, 6, 7, 9, 9, 7, 7, 7, 5, 4, 7, 8, 7, 8, 10, 8, 6, 6, 6, 5, 6, 8, 9, 8, 8, 8, 7, 5, 5, 7, 7, 6, 9, 10, 8, 6, 7, 6, 4, 6, 8, 7, 7, 10, 9, 6, 6, 7, 6, 5, 8, 9, 8, 8, 9, 7, 5, 6, 6, 6, 6, 8, 10, 8, 7, 7, 6, 5, 5, 7, 8, 7, 9, 9, 7, 5, 7, 6, 5, 6, 9, 8, 7, 8, 8, 5, 5, 7, 6, 6, 8, 9, 7, 6, 7, 7, 5, 6, 7, 8, 7, 8, 8, 7, 6, 7, 7, 6, 7, 8, 8, 7, 7, 8, 6, 5, 7, 7, 6, 7, 9, 8, 6, 8, 8, 6, 5, 8, 7, 6, 7, 9, 7, 6, 7, 7, 6, 7, 8, 7, 7, 8, 8, 7, 6, 7, 7, 6, 7, 8, 8, 7, 8, 8, 6, 6, 7, 7, 6, 7, 8, 8, 6, 7, 7, 6, 6, 7, 7, 7, 7, 9, 7, 6, 7, 7, 6, 6, 8, 8, 7, 8, 8, 7, 6, 7, 7, 6, 7, 8, 8, 7, 7, 8, 6, 5, 6, 7, 7, 7, 8, 8, 6, 6, 7, 6, 6, 8, 8, 7, 7, 8, 7, 6, 6, 7, 6, 7, 8, 8, 7, 7, 8, 6, 6, 7, 7, 7, 7, 8, 8, 7, 7, 7, 6, 6, 7, 8, 7, 7, 8, 7, 6, 6, 7, 7, 6, 8, 8, 7, 7, 8, 7, 6, 6, 8, 7, 7, 8, 8, 7, 7, 7, 6, 6, 7, 8, 7, 7, 8, 7, 6, 6, 7, 6, 6, 7, 8, 8, 7, 7, 7, 6, 6, 7, 7, 7, 8, 8, 7, 7, 7, 7, 6, 7, 8, 7, 7, 8, 8, 6, 6, 7, 6, 6, 7, 8, 7, 7, 8, 7, 6, 6, 7, 7, 7, 8, 8, 7, 7, 7, 7, 6, 6, 7, 7, 7, 7, 8, 7, 6, 7, 7, 6, 7, 8, 7, 7, 8, 8, 6, 6, 7, 7, 6, 7, 8, 7, 7, 7, 7, 6, 7, 7, 7, 7, 7, 8, 7, 7, 7, 7, 6, 7, 7, 7, 7, 7, 8, 7, 6, 7, 7, 6, 7, 8, 7, 7, 7, 7, 6, 6, 7, 7, 7, 7, 8, 7, 6, 7, 7, 6, 6, 7, 7, 7, 7, 8, 7, 6, 7, 7, 6, 7, 8, 7, 7, 7, 7, 7, 6, 7, 7, 7, 7, 8, 7, 7, 7, 7, 6, 6, 7, 8, 7, 7, 8, 7, 6, 7, 7, 6, 7, 8, 7, 7, 7, 7, 7, 6, 7, 7, 7, 7, 8, 7, 7, 7, 7, 7, 6, 7, 7, 7, 7, 8, 7, 6, 7, 7, 7, 6, 7, 8, 7, 7, 8, 7, 6, 7, 7, 7, 7, 8, 7, 7, 7, 7, 7, 6, 7, 7, 7, 7, 8, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 6, 7, 7, 7, 7, 7, 8, 7, 7, 7, 7, 6, 7, 7, 7, 7, 8, 7, 7, 7, 7, 7, 6, 7
Sample_08End:

Sample_09:
.db 7, 7, 9, 13, 10, 14, 13, 13, 14, 14, 14, 14, 13, 13, 12, 11, 11, 10, 10, 9, 8, 8, 7, 6, 6, 5, 5, 4, 4, 3, 3, 3, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 3, 3, 3, 3, 3, 3, 4, 4, 4, 4, 4, 4, 4, 5, 5, 5, 5, 5, 5, 5, 5, 5, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 7, 7, 7, 7, 7, 7, 7, 7, 7, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 7, 7, 7, 8, 9, 12, 11, 10, 13, 14, 13, 13, 14, 14, 14, 13, 14, 14, 13, 13, 13, 13, 12, 12, 11, 11, 11, 10, 10, 9, 9, 8, 8, 7, 7, 7, 6, 6, 5, 5, 5, 4, 4, 4, 3, 3, 3, 3, 3, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 3, 3, 3, 3, 3, 3, 3, 3, 3, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 7
Sample_09End:

Sample_10:
.db 8, 9, 2, 4, 8, 11, 12, 11, 8, 4, 2, 0, 1, 3, 7, 8, 10, 11, 9, 9, 10, 9, 9, 10, 9, 8, 7, 6, 6, 5, 5, 6, 5, 5, 4, 4, 4, 5, 6, 7, 7, 8, 8, 9, 9, 9, 9, 9, 9, 9, 8, 8, 7, 7, 6, 6, 6, 6, 6, 6, 6, 6, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 8, 8, 8, 7, 7, 7, 7, 7, 6, 6, 6, 6, 6, 7
Sample_10End:

Sample_11:
.db 7, 7, 7, 7, 8, 6, 6, 8, 7, 6, 9, 7, 5, 9, 5, 7, 7, 11, 2, 9, 6, 3, 10, 6, 7, 5, 7, 6, 2, 8, 6, 7, 8, 6, 8, 11, 8, 4, 10, 9, 0, 7, 12, 3, 7, 9, 9, 6, 6, 10, 6, 8, 4, 8, 6, 4, 7, 11, 4, 7, 8, 4, 10, 10, 5, 11, 6, 7, 5, 9, 7, 7, 5, 9, 4, 3, 11, 4, 8, 7, 6, 9, 6, 7, 7, 5, 7, 8, 6, 8, 8, 5, 10, 8, 3, 10, 8, 6, 7, 8, 6, 8, 5, 8, 4, 10, 5, 8, 6, 9, 7, 7, 8, 8, 5, 9, 5, 5, 8, 7, 7, 7, 6, 8, 5, 8, 8, 5, 9, 6, 7, 8, 6, 8, 6, 7, 9, 6, 7, 6, 9, 5, 7, 8, 5, 9, 5, 9, 9, 5, 9, 6, 8, 6, 8, 7, 6, 7, 8, 6, 8, 5, 9, 7, 7, 7, 8, 7, 8, 6, 7, 8, 5, 7, 7, 6, 7, 7, 6, 7, 8, 7, 7, 6, 8, 5, 8, 7, 5, 8, 8, 7, 8, 7, 7, 5, 8, 6, 8, 7, 8, 7, 8, 8, 7, 6, 9, 7, 8, 6, 7, 8, 6, 8, 6, 8, 7, 6, 7, 6, 7, 7, 7, 7, 7, 8, 6, 7, 6, 7, 8, 6, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 6, 7, 7, 8, 7, 7, 7, 8, 7, 8, 6, 8, 7, 7, 7, 7, 6, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 6, 7, 7, 7, 7, 6, 7, 7, 7, 7, 7, 7, 7, 7, 7, 8, 7, 7, 7, 7, 6, 7, 6, 7, 7, 8, 7, 7, 7, 8, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 8, 7, 7, 7, 7, 7, 7, 7, 8, 7, 7, 7, 7, 6, 8, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 6, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 8, 7
Sample_11End:

Sample_12:
.db 7, 7, 7, 5, 8, 8, 6, 5, 9, 3, 8, 3, 8, 8, 6, 10, 6, 6, 11, 4, 6, 5, 7, 6, 9, 8, 4, 8, 9, 6, 9, 6, 7, 9, 7, 8, 8, 7, 6, 9, 9, 3, 7, 7, 8, 8, 7, 7, 6, 8, 6, 7, 6, 9, 4, 11, 6, 6, 9, 4, 9, 8, 4, 12, 4, 10, 5, 8, 8, 6, 6, 10, 4, 6, 12, 3, 11, 8, 5, 11, 4, 9, 7, 4, 8, 8, 6, 7, 9, 4, 9, 8, 3, 10, 8, 4, 10, 4, 8, 8, 7, 7, 6, 9, 3, 9, 6, 6, 8, 5, 8, 8, 5, 8, 6, 7, 10, 5, 10, 5, 10, 6, 6, 7, 9, 3, 9, 6, 10, 6, 5, 10, 7, 7, 8, 5, 9, 5, 7, 10, 2, 12, 4, 8, 8, 4, 11, 2, 11, 4, 10, 6, 8, 5, 8, 4, 8, 7, 6, 8, 4, 8, 8, 4, 11, 3, 7, 8, 3, 8, 9, 4, 9, 7, 6, 7, 7, 7, 4, 10, 5, 8, 6, 7, 10, 4, 9, 8, 7, 8, 8, 6, 6, 7, 6, 9, 7, 8, 3, 8, 9, 6, 9, 6, 6, 8, 6, 5, 9, 7, 4, 9, 5, 9, 7, 5, 10, 3, 10, 4, 8, 7, 7, 7, 6, 5, 7, 9, 4, 8, 9, 5, 10, 5, 6, 10, 3, 10, 6, 5, 9, 8, 6, 7, 7, 6, 5, 10, 5, 8, 7, 8, 7, 5, 11, 4, 8, 11, 2, 10, 5, 8, 6, 9, 7, 7, 8, 8, 6, 9, 5, 7, 6, 10, 4, 8, 10, 3, 11, 5, 9, 7, 7, 8, 5, 8, 7, 7, 10, 4, 11, 4, 7, 7, 4, 10, 3, 11, 5, 7, 7, 7, 7, 6, 6, 9, 7, 7, 5, 7, 10, 4, 9, 6, 9, 4, 11, 5, 8, 8, 7, 8, 6, 8, 6, 7, 7, 3, 11, 5, 10, 6, 9, 8, 5, 7, 7, 7, 7, 7, 8, 4, 9, 6, 7, 8, 8, 4, 11, 5, 8, 6, 8, 7, 6, 6, 7, 7, 6, 8, 5, 7, 8, 7, 7, 8, 6, 7, 5, 9, 7, 9, 6, 8, 6, 6, 9, 4, 8, 6, 9, 8, 6, 9, 3, 12, 5, 7, 8, 6, 9, 8, 7, 8, 7, 5, 7, 11, 4, 8, 8, 5, 9, 6, 8, 7, 6, 8, 7, 8, 7, 5, 11, 6, 9, 7, 6, 8, 6, 6, 9, 5, 7, 7, 6, 8, 6, 8, 9, 6, 6, 8, 5, 8, 6, 5, 9, 4, 6, 8, 6, 8, 7, 5, 11, 5, 9, 8, 5, 9, 8, 5, 8, 7, 6, 8, 6, 7, 7, 7, 5, 8, 5, 9, 7, 5, 9, 8, 4, 10, 4, 7, 7, 6, 9, 5, 9, 7, 7, 8, 5, 9, 6, 5, 9, 5, 8, 7, 4, 9, 7, 7, 7, 5, 8, 5, 7, 9, 3, 11, 5, 8, 7, 7, 7, 5, 9, 4, 7, 8, 5, 7, 7, 6, 8, 4, 8, 7, 7, 7, 7, 5, 7, 7, 6, 10, 6, 8, 7, 8, 5, 8, 7, 7, 8, 7, 6, 6, 8, 4, 9, 7, 6, 7, 6, 7, 8, 6, 6, 7, 7, 6, 8, 6, 7, 8, 6, 7, 7, 6, 9, 4, 8, 8, 5, 10, 4, 7, 8, 6, 7, 7, 7, 5, 8, 6, 7, 8, 6, 6, 7, 5, 9, 6, 7, 8, 8, 9, 5, 6, 8, 4, 10, 5, 7, 10, 5, 7, 7, 7, 5, 9, 4, 9, 6, 8, 8, 5, 9, 5, 7, 7, 8, 6, 8, 6, 6, 9, 4, 7, 9, 4, 9, 5, 9, 7, 6, 8, 4, 10, 6, 7, 8, 6, 8, 6, 7, 7, 6, 9, 5, 7, 7, 6, 9, 4, 9, 6, 6, 7, 9, 5, 7, 7, 7, 7, 6, 8, 8, 6, 6, 6, 7, 8, 7, 5, 9, 7, 6, 9, 7, 6, 8, 8, 4, 8, 6, 7, 6, 8, 6, 7, 8, 7, 6, 9, 7, 5, 8, 7, 7, 9, 6, 8, 6, 7, 8, 6, 8, 7, 6, 11, 5, 9, 8, 6, 7, 8, 6, 7, 7, 9, 5, 8, 7, 6, 9, 6, 7, 8, 5, 6, 9, 6, 9, 6, 7, 6, 7, 8, 5, 8, 5, 10, 7, 6, 9, 3, 11, 6, 7, 8, 6, 8, 8, 7, 8, 7, 5, 7, 10, 5, 8, 7, 6, 7, 7, 8, 6, 8, 7, 7, 8, 6, 5, 10, 4, 9, 7, 6, 8, 6, 8, 8, 5, 8, 6, 8, 7, 5, 8, 7, 7, 7, 6, 7, 7, 8, 5, 8, 5, 7, 7, 7, 5, 9, 6, 7, 7, 7, 7, 6, 7, 8, 5, 9, 5, 7, 8, 6, 9, 4, 10, 5, 8, 7, 7, 8, 6, 8, 7, 7, 8, 6, 8, 6, 8, 6, 8, 7, 7, 9, 4, 10, 6, 8, 8, 5, 9, 6, 8, 7, 8, 7, 7, 7, 5, 9, 6, 8, 6, 7, 6, 8, 7, 7, 8, 5, 10, 6, 8, 6, 7, 7, 7, 6, 8, 7, 6, 7, 9, 5, 9, 4, 8, 7, 5, 7, 8, 6, 8, 6, 9, 6, 8, 6, 9, 5, 6, 8, 5, 10, 5, 7, 9, 6, 7, 8, 5, 8, 7, 8, 7, 8, 7, 6, 8, 7, 6, 8, 7, 7, 8, 7, 5, 9, 7, 5, 9, 5, 8, 6, 7, 8, 5, 10, 4, 9, 6, 7, 8, 6, 7, 7, 9, 6, 8, 8, 5, 9, 7, 6, 10, 6, 6, 9, 5, 8, 8, 5, 7, 8, 8, 6, 8, 7, 6, 7, 7, 6, 7, 8, 5, 9, 7, 6, 8, 7, 8, 6, 8, 6, 9, 6, 7, 8, 5, 8, 6, 8, 7, 6, 8, 5, 9, 7, 8, 7, 8, 8, 6, 8, 8, 7, 8, 6, 7, 8, 5, 8
Sample_12End:

Sample_13:
.db 1, 1, 2, 3, 6, 9, 10, 11, 10, 10, 9, 10, 10, 10, 10, 10, 11, 11, 12, 12, 13, 13, 13, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 13, 13, 13, 12, 11, 11, 11, 10, 10, 9, 8, 8, 8, 7, 6, 5, 5, 5, 4, 3, 2, 2, 1, 1, 1, 1, 1, 1, 1, 2, 2, 2, 2, 3, 3, 3, 3, 3, 3, 3, 3, 4, 4, 4, 4, 4, 4, 4, 4, 4, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 7, 7, 8, 8, 9, 10, 11, 11, 11, 12, 12, 13, 13, 13, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 12, 12, 12, 11, 11, 11, 10, 10, 10, 10, 10, 10, 10, 9, 9, 9, 8, 8, 8, 7, 7, 7, 7, 6, 6, 6, 5, 5, 5, 4, 4, 4, 4, 3, 3, 2, 2, 2, 2, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 2, 2, 2, 2, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 7, 7, 7, 8, 8, 9, 9, 10, 10, 10, 11, 11, 12, 12, 12, 12, 12, 12, 12, 12, 13, 13, 13, 13, 13, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 13, 13, 13, 13, 13, 13, 13, 13, 12, 12, 12, 12, 11, 11, 11, 11, 11, 10, 10, 10, 10, 10, 10, 10, 10, 10, 9, 9, 9, 8, 8, 8, 8, 7, 7, 7, 7, 7, 7, 6, 6, 6, 5, 5, 5, 5, 5, 4, 4, 4, 4, 3, 3, 3, 2, 2, 2, 2, 2, 2, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 2, 2, 2, 2, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 7, 7, 7, 7, 7, 8, 9, 9, 9, 9, 10, 10, 10, 11, 11, 11, 12, 12, 12, 12, 12, 12, 12, 12, 12, 13, 13, 13, 13, 13, 13, 13, 14, 14, 14, 14, 14, 14, 14, 14, 13, 13, 13, 13, 13, 13, 13, 13, 13, 12, 12, 12, 12, 12, 11, 11, 11, 11, 11, 11, 11, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 9, 9, 9, 8, 8, 8, 8, 8, 7, 7, 7, 7, 7, 7, 6, 6, 6, 6, 5, 5, 5, 5, 5, 5, 4, 4, 4, 4, 3, 3, 3, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 7, 7, 7, 7, 7, 8, 8, 9, 9, 9, 9, 9, 10, 10, 10, 11, 11, 11, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 12, 12, 12, 12, 12, 12, 11, 11, 11, 11, 11, 11, 11, 11, 11, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 9, 9, 9, 8, 8, 8, 8, 8, 7, 7, 7, 7, 7, 7, 7, 7, 7, 6, 6, 6, 5, 5, 5, 5, 5, 5, 5, 5, 4, 4, 4, 4, 3, 3, 3, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 4, 4, 4, 4, 4, 4, 4, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6
Sample_13End:

Sample_14:
.db 7, 8, 8, 9, 9, 9, 9, 9, 8, 8, 7, 6, 6, 4, 3, 3, 2, 3, 2, 2, 4, 4, 2, 4, 7, 8, 9, 8, 11, 11, 12, 11, 14, 14, 13, 11, 11, 13, 12, 8, 9, 8, 7, 5, 6, 4, 4, 2, 2, 2, 4, 3, 2, 4, 4, 6, 5, 7, 6, 8, 8, 10, 10, 10, 11, 11, 10, 10, 11, 8, 11, 8, 7, 7, 8, 5, 6, 4, 4, 5, 4, 3, 2, 4, 3, 4, 4, 5, 5, 6, 7, 8, 7, 9, 10, 9, 9, 10, 11, 11, 11, 9, 11, 8, 9, 9, 7, 8, 6, 5, 5, 5, 4, 4, 4, 4, 4, 5, 3, 6, 5, 6, 7, 7, 7, 9, 8, 8, 10, 9, 10, 10, 9, 9, 10, 9, 9, 9, 7, 7, 7, 7, 6, 5, 6, 5, 4, 4, 5, 5, 3, 4, 6, 5, 6, 6, 7, 7, 8, 9, 8, 9, 9, 9, 10, 9, 10, 8, 10, 8, 8, 8, 8, 6, 6, 7, 7, 4, 6, 5, 5, 5, 5, 5, 4, 6, 6, 6, 6, 7, 7, 8, 7, 8, 8, 9, 9, 9, 9, 9, 8, 9, 8, 8, 8, 7, 7, 7, 6, 6, 6, 5, 5, 6, 5, 5, 5, 6, 6, 7, 5, 7, 7, 7, 8, 7, 8, 9, 9, 9, 8, 8, 9, 8, 9, 7, 8, 7, 7, 7, 7, 6, 6, 6, 7, 6, 5, 6, 5, 6, 6, 6, 6, 7, 7, 7, 7, 8, 8, 8, 8, 9, 8, 8, 9, 8, 8, 8, 7, 8, 7, 8, 7, 7, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 7, 7, 7, 8, 7, 7, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 7, 7, 7, 7, 7, 7, 6, 7, 6, 6, 6, 6, 6, 6, 6, 6, 7, 7, 7, 7, 7, 8, 7, 8, 8, 8, 8, 8, 8, 8, 8, 7, 8, 8, 7, 7, 7, 7, 7, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 7, 7, 7, 7, 7, 7, 7, 8, 7, 8, 8, 8, 7, 8, 8, 7, 7, 7, 7, 7, 7, 7, 7, 7, 6, 7, 6, 6, 6, 6, 7, 6, 7, 7, 7, 7, 7, 7, 7, 7, 7, 8, 8, 8, 8, 7, 8, 8, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 6, 6, 7, 7, 6, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 8, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 6, 7
Sample_14End:

Sample_15:
.db 4, 1, 2, 4, 5, 6, 7, 8, 8, 8, 9, 9, 10, 11, 12, 13, 14, 14, 14, 14, 14, 14, 13, 12, 11, 10, 9, 8, 7, 6, 5, 4, 4, 3, 2, 2, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 2, 2, 3, 3, 4, 4, 5, 6, 6, 7, 7, 8, 9, 9, 10, 10, 11, 11, 12, 12, 12, 13, 13, 13, 13, 13, 14, 14, 13, 13, 13, 13, 13, 13, 12, 12, 12, 11, 11, 10, 10, 9, 9, 8, 8, 7, 7, 6, 6, 5, 5, 4, 4, 4, 3, 3, 3, 2, 2, 2, 2, 2, 1, 1, 1, 1, 2, 2, 2, 2, 2, 2, 3, 3, 3, 4, 4, 5, 5, 5, 6, 6, 7, 7, 8, 8, 9, 9, 9, 10, 10, 11, 11, 11, 11, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 11, 11, 11, 11, 10, 10, 10, 9, 9, 8, 8, 7, 7, 7, 6, 6, 5, 5, 5, 4, 4, 4, 3, 3, 3, 3, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 3, 3, 3, 3, 4, 4, 4, 5, 5, 5, 6, 6, 7, 7, 7, 8, 8, 9, 9, 9, 10, 10, 10, 10, 11, 11, 11, 11, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 11, 11, 11, 11, 11, 10, 10, 10, 9, 9, 9, 8, 8, 8, 7, 7, 7, 6, 6, 5, 5, 5, 5, 4, 4, 4, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 4, 4, 4, 4, 5, 5, 5, 5, 6, 6, 6, 7, 7, 7, 8, 8, 8, 9, 9, 9, 10, 10, 10, 10, 10, 11, 11, 11, 11, 11, 11, 11, 11, 11, 11, 11, 11, 11, 10, 10, 10, 10, 10, 9, 9, 9, 9, 8, 8, 8, 7, 7, 7, 7, 6, 6, 6, 5, 5, 5, 5, 5, 4, 4, 4, 4, 4, 4, 4, 3, 3, 3, 3, 3, 3, 4, 4, 4, 4, 4, 4, 4, 5, 5, 5, 5, 5, 6, 6, 6, 6, 7, 7, 7, 8, 8, 8, 8, 9, 9, 9, 9, 9, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 9, 9, 9, 9, 9, 8, 8, 8, 8, 7, 7, 7, 7, 6, 6, 6, 6, 5, 5, 5, 5, 5, 5, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 5, 5, 5, 5, 5, 5, 6, 6, 6, 6, 6, 7, 7, 7, 7, 8, 8, 8, 8, 8, 9, 9, 9, 9, 9, 9, 9, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 9, 9, 9, 9, 9, 9, 9, 8, 8, 8, 8, 8, 8, 7, 7, 7, 7, 7, 6, 6, 6, 6, 6, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 4, 4, 4, 4, 4, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 6, 6, 6, 6, 6, 6, 7, 7, 7, 7, 7, 8, 8, 8, 8, 8, 8, 8, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 8, 8, 8, 8, 8, 8, 7, 7, 7, 7, 7, 7, 6, 6, 6, 6, 6, 6, 6, 6, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 6, 6, 6, 6, 6, 6, 6, 6, 7, 7, 7, 7, 7, 7, 7, 8, 8, 8, 8, 8, 8, 8, 8, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 8, 8, 8, 8, 8, 8, 8, 8, 8, 7, 7, 7, 7, 7, 7, 7, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 7, 7, 7, 7, 7, 7, 7, 7, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 9, 9, 9, 9, 9, 9, 9, 9, 9, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 7, 7, 7, 7, 7, 7, 7, 7, 7, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 7, 7, 7, 7, 7
Sample_15End:

Sample_16:
.db 7, 9, 6, 7, 7, 3, 9, 9, 9, 1, 8, 8, 4, 11, 7, 7, 10, 0, 9, 9, 8, 5, 7, 7, 8, 9, 6, 6, 7, 11, 6, 6, 6, 5, 9, 8, 5, 8, 7, 7, 9, 4, 7, 7, 6, 6, 7, 8, 10, 6, 6, 7, 9, 3, 6, 8, 10, 6, 6, 6, 8, 3, 8, 8, 7, 8, 6, 8, 10, 1, 10, 7, 3, 11, 6, 7, 6, 8, 8, 7, 6, 8, 8, 7, 6, 6, 9, 7, 6, 6, 7, 7, 8, 7, 8, 7, 7, 4, 9, 7, 6, 8, 8, 7, 6, 10, 6, 7, 7, 6, 7, 8, 8, 5, 9, 7, 6, 8, 8, 7, 6, 5, 8, 8, 7, 3, 10, 8, 7, 6, 9, 7, 6, 9, 6, 8, 8, 7, 5, 8, 8, 6, 6, 6, 6, 10, 6, 6, 6, 8, 9, 7, 7, 6, 6, 8, 8, 5, 9, 7, 6, 7, 7, 7, 7, 7, 7, 6, 7, 8, 5, 7, 7, 7, 7, 6, 7, 9, 4, 8, 7, 5, 7, 7, 7, 5, 9, 7, 7, 7, 7, 7, 7, 7, 7, 8, 7, 6, 8, 6, 7, 9, 7, 7, 6, 6, 7, 7, 7, 6, 9, 7, 7, 8, 5, 8, 7, 7, 6, 7, 6, 6, 7, 7, 7, 7, 6, 8, 7, 6, 8, 6, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 6, 8, 7, 7, 7, 7, 7, 7, 9, 7, 6, 7, 9, 6, 6, 6, 7, 8, 8, 7, 6, 8, 7, 7, 8, 7, 7, 7, 7, 7, 7, 7, 7, 6, 7, 7, 8, 6, 7, 7, 7, 7, 7, 7, 8, 6, 7, 8, 8, 6, 6, 7, 7, 6, 7, 7, 7, 7, 7, 7, 6, 8, 7, 7, 7, 7, 7, 7, 7, 6, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 6, 9, 7, 7, 8, 7, 7, 7, 7, 6, 7, 7, 8, 6, 7, 7, 7, 7, 7, 7, 7, 8, 7, 7, 8, 6, 7, 7, 7, 7, 7, 7, 6, 8, 7, 7, 7, 7, 7, 7, 7, 8, 7, 7, 7, 6, 7, 8, 8, 6, 7, 7, 7, 6, 7, 7, 7, 6, 7, 7, 7, 6, 7, 7, 7, 6, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 8, 7, 7, 7, 8, 7, 7, 7, 6, 8, 7, 7, 8, 7, 7, 7, 6, 8, 7, 7, 7, 7, 7, 7, 6, 8, 7, 7, 7, 7, 7, 7, 8, 6, 7, 7, 8, 6, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 8, 6, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 6, 7, 7, 7, 7, 7, 7, 8, 7, 7, 7, 6, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 8, 6, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 6, 8, 7, 7, 7, 7, 7, 7, 8, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 6, 7
Sample_16End:

Sample_17:
.db 7, 8, 12, 10, 14, 13, 14, 13, 14, 13, 13, 12, 11, 10, 9, 8, 7, 7, 6, 5, 4, 4, 3, 3, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 3, 3, 3, 3, 4, 4, 4, 4, 4, 5, 5, 5, 5, 5, 5, 5, 6, 6, 6, 6, 6, 6, 6, 6, 7, 7, 7, 7, 7, 7, 7, 8, 8, 8, 8, 8, 8, 8, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8
Sample_17End:

Sample_18:
.db 9, 4, 11, 11, 4, 0, 3, 8, 11, 9, 9, 10, 8, 6, 5, 6, 5, 4, 5, 7, 8, 9, 9, 9, 9, 8, 7, 6, 6, 6, 6, 7, 7, 7, 7, 7, 7, 7, 7, 8, 8, 7, 7, 6, 6, 6
Sample_18End:

Sample_19:
.db 6, 8, 6, 7, 9, 7, 11, 9, 3, 6, 5, 6, 8, 7, 6, 11, 4, 9, 7, 3, 9, 6, 10, 8, 8, 4, 11, 7, 4, 10, 11, 7, 9, 7, 9, 3, 4, 7, 9, 7, 5, 8, 8, 5, 8, 10, 6, 8, 8, 8, 10, 8, 9, 7, 8, 9, 5, 7, 7, 8, 8, 5, 6, 8, 8, 7, 6, 6, 5, 8, 9, 9, 5, 6, 6, 7, 7, 6, 5, 7, 7, 7, 6, 8, 7, 6, 7, 7, 7, 6, 5, 7, 8, 7, 7, 5, 6, 7, 7, 8, 6, 7, 6, 8, 8, 8, 6, 6, 7, 7, 8, 7, 7, 6, 7, 7, 7, 7, 7, 7, 6, 7, 7, 7, 7, 6, 7, 7, 6, 7, 7, 7, 7, 7, 6, 7, 7, 7, 7, 7, 7, 7, 7, 7, 6, 6, 7, 7, 7, 7, 7, 7, 7, 7, 7, 8, 7, 7, 7, 8, 7, 7, 8, 7
Sample_19End:

Sample_20:
.db 7, 7, 7, 6, 8, 6, 7, 9, 7, 11, 9, 3, 6, 5, 6, 8, 7, 6, 11, 4, 9, 7, 3, 9, 6, 10, 8, 8, 4, 11, 7, 4, 10, 11, 7, 9, 7, 9, 3, 4, 7, 9, 7, 5, 8, 8, 5, 8, 10, 6, 8, 8, 8, 10, 8, 9, 7, 8, 9, 5, 7, 7, 8, 8, 5, 6, 8, 8, 7, 6, 6, 5, 8, 9, 9, 5, 6, 6, 7, 7, 6, 5, 7, 7, 7, 6, 8, 7, 6, 7, 7, 7, 6, 5, 7, 8, 7, 7, 5, 6, 7, 7, 8, 6, 7, 6, 8, 8, 8, 6, 6, 7, 7, 8, 7, 7, 6, 7, 7, 7, 7, 7, 7, 6, 7, 7, 7, 7, 6, 7, 7, 6, 7, 7, 7, 7, 7, 6, 7, 7, 7, 7, 7, 7, 7, 7, 7, 6, 6, 7, 7, 7, 7, 7, 7, 7, 7, 7, 8, 7, 7, 7, 8, 7, 7, 8
Sample_20End:

Sample_21:
.db 14, 14, 14, 14, 14, 14, 14, 8, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 4, 13, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 10, 4, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 5, 8, 12, 13, 14, 14, 14, 14, 14, 14, 14, 13, 12, 9, 6, 3, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 6, 9, 12, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 12, 10, 7, 5, 3, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 2, 3, 4, 5, 5, 6, 6, 6, 6, 5, 5, 5, 4, 4, 3, 3, 3, 2, 2, 2, 2, 2, 3, 3, 4, 5, 5, 6, 7, 8, 9, 10, 10, 11, 11, 12, 12, 12, 12, 12, 11, 11, 10, 9, 8, 7, 6, 5, 4, 3, 3, 2, 2, 1, 1, 1, 1, 2, 2, 3, 4, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 13, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 13, 13, 13, 13, 12, 12, 12, 12, 12, 12, 11, 11, 11, 11, 11, 11, 11, 11, 11, 10, 10, 10, 9, 9, 8, 8, 7, 6, 5, 4, 4, 3, 2, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 2, 2, 3, 3, 4, 4, 4, 5, 5, 5, 6, 6, 6, 6, 6, 6, 7, 7, 7, 7, 7, 7, 7, 8, 8, 8, 8, 8, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 8, 8, 8, 7, 7, 6, 6, 6, 5, 5, 5, 4, 4, 4, 4, 4, 4, 4, 5, 5, 5, 6, 6, 7, 7, 8, 8, 9, 9, 10, 10, 11, 11, 12, 12, 12, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 12, 12, 12, 12, 11, 11, 11, 10, 10, 9, 9, 9, 8, 8, 7, 7, 6, 6, 5, 5, 4, 4, 3, 3, 3, 2, 2, 2, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 2, 2, 2, 3, 3, 3, 3, 4, 4, 4, 4, 5, 5, 5, 5, 5, 6, 6, 6, 6, 6, 6, 6, 6, 6, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 8, 8, 8, 8, 8, 9, 9, 9, 9, 9, 10, 10, 10, 10, 10, 11, 11, 11, 11, 11, 11, 11, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 11, 11, 11, 11, 11, 10, 10, 10, 9, 9, 9, 8, 8, 8, 7, 7, 6, 6, 5, 5, 5, 4, 4, 3, 3, 3, 2, 2, 2, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 2, 2, 3, 3, 3, 3, 4, 4, 5, 5, 5, 6, 6, 6, 7, 7, 7, 8, 8, 8, 8, 9, 9, 9, 9, 9, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 9, 9, 9, 9, 9, 9, 9, 8, 8, 8, 8, 8, 8, 8, 8, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 8, 8, 8, 8, 8, 8, 8, 9, 9, 9, 9, 9, 9, 10, 10, 10, 10, 10, 11, 11, 11, 11, 11, 11, 11, 11, 11, 11, 11, 11, 11, 11, 11, 10, 10, 10, 10, 9, 9, 9, 8, 8, 7, 7, 7, 6, 6, 5, 5, 5, 4, 4, 3, 3, 3, 2, 2, 2, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 2, 2, 2, 3, 3, 3, 4, 4, 5, 5, 5, 6, 6, 7, 7, 7, 8, 8, 8, 9, 9, 9, 9, 9, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 9, 9, 9, 9, 9, 9, 9, 8, 8, 8, 8, 8, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 8, 8, 8, 8, 9, 9, 9, 9, 9, 10, 10, 10, 10, 11, 11, 11, 11, 11, 11, 11, 11, 11, 11, 11, 11, 11, 11, 11, 11, 11, 10, 10, 10, 10, 9, 9, 9, 8, 8, 8, 7, 7, 7, 6, 6, 5, 5, 5, 4, 4, 4, 3, 3, 3, 3, 2, 2, 2, 2, 2, 1, 1, 1, 1, 1, 1, 1, 1, 2, 2, 2, 2, 2, 2, 3, 3, 3, 3, 4, 4, 4, 5, 5, 5, 6, 6, 6, 6, 7, 7, 7, 8, 8, 8, 8, 8, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 9, 9, 9, 9, 9, 9, 9, 9, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 9, 9, 9, 9, 9, 8, 8, 8, 8, 8, 7, 7, 7, 7, 6, 6, 6, 5, 5, 5, 5, 4, 4, 4, 4, 3, 3, 3, 3, 3, 3, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 3, 3, 3, 3, 3, 3, 4, 4, 4, 4, 4, 5, 5, 5, 6, 6, 6, 6, 7, 7, 7, 7, 8, 8, 8, 8, 8, 9, 9, 9, 9, 9, 9, 9, 10, 10, 10, 10, 10, 10, 10, 10
Sample_21End:

Sample_22:
.db 5, 6, 4, 5, 9, 7, 9, 10, 5, 5, 7, 4, 5, 5, 7, 7, 9, 5, 4, 6, 7, 7, 7, 7, 8, 6, 8, 9, 7, 5, 7, 7, 7, 8, 6, 10, 11, 6, 7, 9, 7, 7, 8, 8, 7, 7, 7, 8, 5, 6, 9, 8, 7, 7, 6, 7, 6, 10, 6, 5, 9, 6, 9, 5, 7, 9, 6, 9, 9, 6, 5, 7, 7, 7, 9, 8, 9, 10, 7, 6, 2, 7, 8, 9, 7, 9, 8, 7, 8, 7, 7, 6, 6, 8, 9, 7, 7, 9, 8, 7, 8, 9, 6, 9, 5, 7, 9, 6, 8, 7, 7, 7, 7, 8, 9, 7, 7, 8, 7, 9, 10, 6, 7, 6, 9, 6, 6, 8, 8, 5, 9, 5, 5, 8, 7, 6, 7, 11, 8, 6, 8, 7, 8, 5, 7, 5, 7, 5, 10, 7, 6, 6, 9, 7, 7, 8, 7, 6, 9, 6, 8, 6, 7, 7, 10, 8, 6, 7, 6, 9, 6, 8, 6, 8, 6, 5, 7, 5, 7, 7, 6, 8, 6, 8, 6, 7, 6, 8, 7, 7, 9, 8, 8, 7, 6, 7, 7, 7, 7, 9, 9, 8, 6, 8, 5, 7, 7, 6, 8, 7, 7, 5, 8, 9, 6, 9, 7, 7, 6, 9, 8, 8, 6, 5, 7, 6, 8, 5, 6, 7, 8, 9, 8, 9, 7, 5, 8, 8, 7, 7, 6, 6, 7, 9, 8, 7, 8, 9, 8, 9, 5, 6, 7, 8, 6, 6, 8, 6, 8, 9, 9, 8, 8, 8, 9, 10, 6, 7, 6, 7, 7, 8, 8, 7, 7, 6, 8, 7, 6, 9, 8, 7, 7, 7, 7, 8, 7, 8, 6, 10, 8, 8, 7, 5, 7, 7, 8, 5, 6, 7, 6, 6, 6, 6, 5, 6, 7, 7, 6, 6, 8, 6, 6, 7, 7, 7, 7, 7, 7, 7, 7, 6, 6, 6, 7, 7, 8, 7, 7, 8, 8, 8, 8, 8, 5, 8, 8, 8, 8, 6, 7, 7, 7, 5, 5, 6, 6, 8, 8, 8, 7, 8, 8, 7, 7, 8, 7, 8, 8, 8, 7, 7, 6, 7, 4, 5, 5, 6, 7, 6, 7, 8, 7, 7, 7, 8, 7, 9, 8, 6, 7, 7, 8, 7, 10, 8, 7, 6, 9, 7, 7, 6, 5, 6, 8, 7, 6, 8, 6, 6, 6, 8, 8, 8, 5, 7, 7, 8, 6, 7, 6, 7, 7, 6, 7, 8, 7, 6, 8, 7, 8, 7, 7, 7, 8, 7, 7, 7, 6, 8, 8, 8, 7, 6, 8, 7, 8, 6, 8, 7, 6, 6, 7, 8, 8, 6, 6, 7, 6, 8, 7, 6, 8, 6, 7, 7, 6, 7, 7, 7, 8, 8, 6, 5, 7, 6, 8, 7, 6, 7, 8, 6, 8, 7, 7, 8, 6, 6, 7, 6, 7, 6, 7, 7, 8, 7, 6, 6, 8, 7, 6, 8, 7, 7, 7, 6, 8, 6, 6, 7, 6, 7, 6, 8, 7, 8, 6, 6, 6, 7, 8, 8, 7, 6, 7, 7, 9, 8, 7, 6, 6, 7, 7, 6, 7, 7, 7, 7, 7, 6, 7, 7, 7, 8, 8, 7, 7, 6, 6, 8, 7, 6, 7, 7, 6, 7, 6, 6, 6, 7, 6, 7, 7, 6, 8, 7, 6, 6, 8, 7, 7, 7, 6, 7, 7, 7, 7, 6, 7, 6, 6, 6, 7, 6, 8, 8, 9, 7, 7, 7, 6, 7, 6, 8, 8, 7, 5, 7, 7, 7, 8, 7, 8, 7, 7, 8, 7, 6, 7, 7, 7, 8, 6, 7, 8, 7, 8, 8, 8, 8, 7, 6, 7, 8, 7, 7, 7, 6, 8, 7, 7, 7, 8, 7, 8, 8, 6, 7, 7, 7, 8, 6, 5, 8, 7, 8, 7, 7, 7, 6, 7, 6, 7, 7, 7, 8, 6, 7, 6, 8, 7, 7, 8, 7, 7, 7, 8, 7, 8, 7, 7, 7, 7, 6, 7, 7, 8, 7, 7, 7, 6, 7, 6, 8, 6, 7, 7, 7, 8, 8, 8, 7, 7, 7, 7, 8, 6, 6, 7, 7, 7, 7, 8, 8, 7, 7, 8, 7, 6, 7, 6, 7, 7, 7, 7, 7, 7, 6, 7, 8, 7, 7, 7, 8, 7, 7, 7, 7, 7, 7, 7, 8, 7, 8, 7, 6, 7, 6, 6, 7, 7, 7, 6, 8, 7, 8, 8, 8, 8, 7, 6, 6, 7, 7, 7, 8, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 8, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 8, 7, 7, 7, 8, 7, 8, 8, 7, 7, 6, 7, 6, 7, 7, 8, 7, 7, 8, 7, 7, 6, 6, 6, 8, 7, 7, 7, 7, 7, 6, 7, 7, 7, 6, 7, 7, 7, 8, 6, 8, 7, 7, 7, 7, 6, 8, 7, 7, 6, 7, 7, 7, 7, 7, 6, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 8, 7, 8, 7, 7, 8, 7, 7, 7, 7, 7, 7, 6, 6, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 8, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 8, 7, 8, 7, 7, 7, 7, 8, 7, 7, 7, 7, 7, 7, 7, 7, 7, 8, 8, 7, 7, 7, 7, 7, 7, 7, 7, 7, 6, 7, 7, 7, 8, 8, 7, 7, 7, 7, 7, 6, 7, 7, 7, 7, 7, 7, 7, 7, 8, 7, 7, 6, 7, 7, 7, 7, 7, 7, 7, 7, 8, 7, 7, 7, 7, 8, 6, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 6, 7, 7, 7, 7, 7, 7, 6, 7, 8, 7, 7, 6, 7, 7, 7, 7, 7, 7, 6, 7, 7, 8, 7, 7, 8, 7, 8, 7, 7, 6, 7, 7, 7, 7, 8, 7, 7, 7, 7, 6, 8, 6, 7, 7, 6
Sample_22End:

Sample_23:
.db 8, 10, 10, 11, 11, 11, 11, 11, 12, 11, 11, 11, 11, 11, 6, 5, 4, 2, 1, 1, 0, 0, 0, 0, 0, 0, 0, 1, 5, 7, 9, 10, 11, 12, 13, 14, 14, 14, 14, 14, 14, 14, 11, 9, 7, 6, 4, 3, 2, 1, 1, 0, 0, 0, 0, 0, 1, 4, 6, 7, 9, 10, 11, 12, 12, 13, 13, 13, 13, 13, 13, 13, 11, 8, 7, 5, 4, 3, 2, 2, 1, 1, 1, 1, 1, 1, 2, 3, 6, 7, 8, 9, 10, 11, 12, 12, 13, 13, 13, 13, 13, 12, 12, 10, 8, 7, 5, 4, 4, 3, 2, 2, 2, 1, 1, 2, 2, 2, 2, 4, 6, 7, 8, 9, 10, 11, 12, 12, 12, 12, 12, 12, 12, 12, 11, 11, 9, 7, 6, 5, 4, 3, 3, 2, 2, 2, 2, 2, 2, 2, 3, 3, 4, 5, 7, 8, 9, 10, 11, 11, 12, 12, 12, 12, 12, 12, 11, 11, 11, 10, 9, 7, 6, 5, 4, 3, 3, 3, 2, 2, 2, 2, 3, 3, 3, 3, 4, 5, 7, 8, 9, 10, 10, 11, 11, 11, 12, 12, 11, 11, 11, 11, 10, 10, 9, 8, 6, 6, 5, 4, 4, 3, 3, 3, 3, 3, 3, 3, 3, 4, 4, 4, 5, 6, 8, 9, 9, 10, 10, 11, 11, 11, 11, 11, 11, 11, 11, 10, 10, 10, 8, 8, 6, 6, 5, 4, 4, 3, 3, 3, 3, 3, 3, 3, 4, 4, 4, 5, 6, 6, 8, 8, 9, 10, 10, 10, 11, 11, 11, 11, 11, 11, 10, 10, 10, 9, 9, 8, 7, 6, 5, 5, 4, 4, 4, 3, 3, 3, 3, 4, 4, 4, 4, 5, 5, 6, 6, 7, 8, 9, 9, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 9, 9, 9, 8, 7, 7, 6, 5, 5, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 5, 5, 5, 6, 7, 7, 8, 9, 9, 10, 10, 10, 10, 10, 10, 10, 10, 10, 9, 9, 9, 9, 8, 7, 7, 6, 5, 5, 5, 4, 4, 4, 4, 4, 4, 4, 4, 5, 5, 5, 5, 6, 7, 7, 8, 9, 9, 9, 10, 10, 10, 10, 10, 10, 10, 9, 9, 9, 9, 9, 8, 7, 7, 6, 6, 5, 5, 5, 4, 4, 4, 4, 4, 4, 5, 5, 5, 5, 5, 6, 6, 7, 7, 8, 8, 9, 9, 9, 9, 10, 10, 10, 9, 9, 9, 9, 9, 9, 8, 8, 7, 7, 7, 6, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 6, 6, 6, 7, 7, 8, 8, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 8, 8, 8, 7, 7, 7, 6, 6, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 6, 6, 6, 6, 7, 7, 7, 8, 8, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 8, 8, 8, 7, 7, 7, 7, 6, 6, 6, 5, 5, 5, 5, 5, 5, 5, 5, 5, 6, 6, 6, 6, 7, 7, 7, 7, 8, 8, 8, 9, 9, 9, 9, 9, 9, 9, 9, 8, 8, 8, 8, 8, 7, 7, 7, 7, 6, 6, 6, 5, 5, 5, 5, 5, 5, 5, 6, 6, 6, 6, 6, 6, 7, 7, 7, 7, 8, 8, 8, 8, 9, 9, 9, 9, 9, 9, 8, 8, 8, 8, 8, 8, 7, 7, 7, 7, 6, 6, 6, 6, 6, 5, 5, 5, 6, 6, 6, 6, 6, 6, 6, 6, 7, 7, 7, 7, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 7, 7, 7, 7, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 7, 7, 7, 7, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 7, 7, 7, 7, 7, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 7, 7, 7, 7, 7, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 7, 7, 7, 7, 7, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 7, 7, 7, 7, 7, 7, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 7, 7, 7, 7, 7, 7, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 7, 7, 7, 7, 7, 7, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 7, 7, 7, 7, 7, 7, 7, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 7, 7, 7, 7, 7, 7, 7, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 7, 7, 7, 7, 7, 7, 7, 7, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 7, 7, 7, 7, 7, 7, 7, 7, 7, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 7, 7, 7, 7, 7, 7, 7, 7, 7, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 6, 6, 6, 6, 6, 6, 6, 6, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 8, 8, 8, 8, 8, 8, 8, 8, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 6, 6, 6, 6, 6, 6, 6, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 8, 8, 8, 8
Sample_23End:

Sample_24:
.db 7, 11, 9, 10, 1, 8, 7, 5, 4, 10, 6, 6, 2, 10, 3, 10, 6, 7, 7, 8, 9, 9, 9, 5, 10, 4, 7, 10, 3, 6, 8, 5, 10, 6, 8, 6, 6, 8, 5, 6, 7, 7, 7, 4, 8, 8, 7, 6, 7, 8, 7, 6, 7, 8, 7, 8, 7, 8, 6, 8, 7, 7, 7, 8, 7, 6, 6, 8, 8, 7, 8, 7, 6, 7, 8, 6, 7, 7, 7, 8, 7, 7, 7, 8, 7, 6, 7, 7, 7, 7, 7, 7, 7, 7, 7, 6, 8, 7, 6, 7, 7, 7, 7, 7, 7, 8, 7, 8, 7, 7, 7, 7, 7, 7, 7, 7, 7, 8
Sample_24End:

Sample_25:
.db 7, 10, 10, 10, 12, 13, 13, 13, 13, 13, 13, 12, 14, 14, 12, 14, 14, 11, 12, 11, 10, 10, 11, 11, 10, 9, 9, 8, 7, 7, 7, 6, 4, 4, 3, 3, 2, 2, 1, 1, 1, 1, 0, 0, 0, 0, 1, 1, 0, 1, 1, 2, 2, 3, 3, 4, 4, 4, 5, 6, 6, 6, 7, 8, 8, 8, 8, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 8, 8, 8, 7, 7, 8, 8, 7, 7, 8, 7, 7, 7, 6, 7, 6, 6, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 7, 7, 7, 7, 7, 7, 7, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 6, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 7, 7, 7, 7, 6, 7, 7, 7, 7, 7, 7, 7, 7, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 7, 7, 7, 7, 8, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 8, 8, 7, 8, 8, 8, 8, 8, 8, 7, 8, 8
Sample_25End:

Sample_26:
.db 7, 5, 5, 4, 4, 5, 12, 10, 8, 11, 11, 10, 9, 8, 6, 7, 5, 3, 4, 2, 1, 3, 3, 4, 6, 7, 7, 9, 9, 10, 11, 11, 11, 10, 10, 11, 10, 9, 7, 7, 5, 5, 4, 3, 4, 5, 4, 5, 6, 6, 7, 8, 8, 10, 10, 10, 10, 9, 8, 8, 7, 6, 6, 6, 6, 5, 4, 6, 5, 5, 6, 6, 7, 7, 7, 7, 9, 9, 9, 9, 8, 8, 8, 8, 7, 7, 6, 6, 6, 5, 5, 5, 6, 7, 7, 7, 7, 8, 8, 7, 7, 7, 7, 8, 7, 8, 8, 8, 8, 7, 7, 6, 6, 6, 6, 6, 6, 6, 6, 7, 7, 8, 8, 8, 8, 8, 8, 8, 7, 7, 7, 7, 7, 7, 7, 7, 7, 6, 7, 6, 6, 7, 7, 7, 7, 8, 8, 8, 8, 8, 7, 8, 7, 7, 7, 7, 6, 6, 6, 6, 6, 7, 7, 7, 7, 7, 8, 9, 8, 8, 7, 7, 7, 7, 7, 7, 7, 7, 7, 6, 6, 6, 7, 7, 7, 7, 7, 7, 8, 8, 8, 8, 8, 7, 7, 7, 7, 7, 7, 7, 6, 6, 7, 7, 7, 7, 7, 7, 7, 7, 8, 8, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 6, 6, 6, 6, 6, 7, 7, 7, 8, 8, 8, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 6, 6, 7, 7, 6, 7, 7, 7, 7, 8, 8, 8, 8, 7, 7, 8, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 6, 7, 6, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 8, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 8, 7, 7, 7, 8, 7, 7, 7, 7, 7, 7, 7, 6, 7, 7, 6, 7, 7, 7, 7, 7, 7, 7, 7, 8, 7, 7, 7, 7, 7, 7, 7, 7, 7, 6, 6, 6
Sample_26End:

Sample_27:
.db 5, 6, 8, 7, 7, 8, 7, 4, 9, 6, 7, 6, 6, 3, 8, 6, 5, 10, 6, 7, 9, 4, 7, 7, 8, 7, 5, 11, 5, 6, 7, 5, 8, 8, 8, 9, 9, 5, 8, 6, 9, 9, 8, 8, 8, 5, 7, 8, 8, 7, 7, 7, 7, 8, 6, 10, 5, 9, 5, 7, 8, 5, 9, 6, 6, 8, 7, 5, 8, 6, 8, 6, 6, 7, 9, 7, 7, 9, 4, 8, 7, 6, 6, 9, 6, 9, 7, 5, 9, 5, 6, 10, 7, 6, 7, 6, 6, 9, 5, 8, 9, 5, 7, 8, 7, 6, 9, 7, 6, 9, 6, 5, 8, 8, 6, 8, 6, 6, 8, 6, 7, 7, 7, 11, 6, 8, 8, 7, 6, 8, 6, 6, 9, 6, 6, 8, 6, 6, 8, 5, 7, 8, 6, 8, 9, 5, 8, 7, 6, 8, 7, 7, 8, 6, 7, 8, 5, 7, 8, 6, 8, 8, 6, 7, 8, 5, 8, 7, 8, 7, 8, 8, 6, 8, 6, 6, 9, 5, 6, 8, 6, 7, 8, 5, 7, 9, 6, 6, 8, 7, 5, 9, 6, 6, 8, 7, 7, 8, 6, 7, 7, 7, 7, 7, 6, 8, 6, 6, 8, 7, 7, 8, 7, 6, 8, 5, 7, 8, 7, 6, 8, 6, 7, 8, 7, 7, 7, 7, 7, 7, 7, 5, 8, 7, 7, 7, 6, 7, 6, 8, 7, 7, 7, 7, 7, 7, 7, 6, 7, 7, 7, 7, 7, 7, 7, 7, 6, 7, 7, 7, 7, 7, 7, 6, 8, 7, 6, 10, 7, 6, 8, 6, 6, 10, 6, 7, 8, 7, 7, 7, 6, 7, 8, 7, 7, 7, 7, 5, 7, 7, 9, 8, 6, 8, 6, 7, 6, 7, 8, 7, 8, 7, 7, 7, 7, 6, 8, 6, 7, 9, 7, 6, 8, 7, 4, 8, 6, 7, 7, 7, 6, 9, 7, 6, 9, 6, 7, 8, 6, 7, 7, 7, 6, 7, 6, 6, 8, 5, 6, 9, 7, 8, 8, 6, 8, 6, 7, 7, 7, 8, 7, 7, 7, 7, 7, 6, 7, 7, 7, 7, 7, 7, 7, 7, 7, 8, 6, 7, 7, 7, 7, 7, 7, 7, 7, 6, 8, 7, 7, 7, 6, 6, 8, 6, 8, 7, 6, 7, 7, 7, 7, 7, 6, 7, 7, 7, 8, 7, 7, 6, 7, 8, 7, 8, 7, 7, 7, 6, 8, 8, 7, 7, 7, 7, 7, 7, 6, 8, 8, 6, 8, 8, 6, 7, 7, 7, 7, 7, 7, 6, 7, 7, 6, 8, 8, 6, 8, 6, 7, 7, 7, 7, 8, 7, 7, 7, 7, 6, 8, 7, 7, 8, 7, 6, 8, 6, 7, 8, 7, 7, 7, 7, 6, 7, 7, 7, 7, 7, 7, 7, 7, 7, 6, 7, 7, 7, 7, 7, 6, 7, 7, 7, 8, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 8, 7, 7, 7, 6, 7, 8, 7, 7, 7, 6, 7, 7, 6, 7, 7, 6, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 6, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 6, 7, 7, 7, 8
Sample_27End:

Sample_28:
.db 9, 8, 8, 12, 9, 8, 7, 9, 7, 5, 7, 4, 6, 6, 5, 8, 8, 8, 6, 5, 5, 4, 5, 6, 6, 5, 7, 8, 8, 9, 9, 10, 9, 8, 8, 7, 7, 6, 7, 6, 7, 7, 6, 6, 7, 7, 7, 8, 8, 7, 7, 7, 7, 7, 6, 6, 7, 7, 8, 7, 8, 7, 8, 8, 7, 7, 6, 6, 5, 6, 6, 6, 6, 7, 8, 7, 7, 8, 7, 9, 8, 8, 8, 8, 8, 7, 7, 7, 6, 5, 5, 6, 6, 7, 7, 7, 7, 7, 8, 8, 7, 7, 7, 7, 7, 7, 8, 7, 7, 7, 7, 7, 7, 7, 7, 6, 6, 6, 7, 6, 7, 7, 7, 8, 8, 8, 8, 8, 8, 7, 7, 8, 7, 7, 6, 6, 6, 5, 6, 7, 7, 7, 7, 7, 7, 7, 8, 8, 8, 8, 8, 8, 7, 7, 7, 7, 7, 6, 6, 6, 7, 7, 6, 7, 7, 7, 7, 7, 7, 7, 7, 7, 8, 8, 8, 8, 8, 8, 8, 7, 6, 6, 6, 6, 6, 6, 6, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 8, 8, 9, 8, 8, 8, 7, 7, 6, 6, 5, 5, 5, 6, 6, 7, 7, 7, 8, 8, 8, 8, 8, 8, 8, 8, 8, 7, 7, 7, 7, 7, 7, 7, 6, 6, 6, 6, 6, 6, 7, 7, 8, 8, 8, 8, 8, 8, 8, 8, 8, 7, 7, 7, 7, 7, 6, 6, 6, 6, 6, 6, 6, 6, 7, 7, 7, 8, 8, 8, 8, 8, 8, 8, 8, 7, 7, 6, 6, 6, 6, 6, 6, 6, 6, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 8, 8, 8, 8, 8, 8, 7, 7, 7, 6, 6, 6, 6, 6, 6, 6, 6, 7, 7, 7, 8, 8, 8, 8, 8, 8, 7, 7, 7, 7, 7, 7, 7, 7, 6, 6, 6, 6, 6, 6, 7, 7, 7, 7, 8, 7, 8, 8, 8, 8, 8, 8, 7, 7, 7, 7, 6, 7, 7, 7, 7, 7, 7, 7, 6, 6, 7, 7, 7, 7, 7, 8, 8, 8, 8, 8, 7, 7, 7, 7, 7, 6, 6, 6, 6, 6, 6, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 8, 8, 8, 7, 7, 7, 7, 7, 6, 6, 6, 6, 6, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 6, 6, 6, 7, 7, 7, 7, 7, 8, 8
Sample_28End:

Sample_29:
.db 7, 7, 5, 6, 7, 7, 5, 8, 7, 5, 4, 4, 8, 9, 8, 9, 7, 7, 8, 4, 7, 9, 9, 10, 7, 8, 9, 3, 5, 9, 9, 10, 5, 6, 11, 4, 5, 7, 7, 8, 5, 6, 12, 8, 6, 6, 6, 11, 7, 5, 9, 8, 9, 7, 3, 8, 8, 5, 7, 8, 11, 9, 1, 4, 8, 7, 7, 6, 11, 10, 2, 4, 7, 8, 7, 3, 9, 13, 6, 4, 4, 8, 10, 4, 6, 12, 9, 5, 2, 5, 10, 6, 5, 9, 8, 7, 3, 6, 11, 6, 3, 7, 10, 11, 6, 3, 9, 7, 6, 6, 7, 12, 8, 4, 6, 7, 6, 6, 6, 10, 8, 3, 7, 8, 9, 6, 2, 8, 10, 7, 7, 6, 8, 8, 3, 7, 9, 8, 7, 6, 9, 10, 4, 4, 8, 9, 9, 5, 6, 10, 6, 5, 6, 8, 10, 5, 6, 10, 7, 6, 5, 7, 12, 7, 5, 9, 9, 8, 4, 4, 10, 9, 6, 6, 6, 9, 6, 4, 9, 10, 7, 6, 6, 10, 8, 3, 6, 9, 9, 6, 3, 8, 10, 5, 5, 7, 10, 10, 4, 7, 10, 7, 6, 5, 9, 11, 5, 4, 8, 8, 7, 4, 6, 11, 7, 5, 6, 8, 10, 5, 4, 9, 9, 7, 6, 6, 10, 6, 3, 8, 10, 9, 5, 3, 9, 9, 5, 6, 7, 9, 7, 4, 9, 9, 6, 5, 5, 10, 9, 4, 6, 9, 8, 6, 3, 9, 12, 6, 5, 5, 9, 9, 5, 6, 9, 6, 5, 6, 9, 10, 4, 4, 9, 9, 8, 4, 6, 10, 8, 5, 7, 8, 9, 5, 4, 9, 9, 7, 5, 6, 10, 7, 4, 7, 9, 8, 5, 4, 10, 10, 6, 5, 6, 8, 8, 5, 8, 10, 6, 5, 5, 9, 9, 5, 6, 9, 9, 6, 4, 7, 10, 6, 6, 8, 9, 9, 4, 5, 8, 8, 6, 7, 8, 9, 5, 4, 8, 9, 8, 5, 6, 10, 8, 4, 6, 7, 8, 6, 5, 10, 9, 6, 4, 6, 10, 8, 5, 7, 9, 7, 6, 4, 8, 9, 6, 6, 7, 9, 7, 4, 6, 9, 7, 7, 7, 9, 9, 4, 4, 8, 9, 7, 6, 7, 10, 7, 4, 6, 7, 9, 6, 6, 9, 8, 6, 5, 6, 9, 7, 5, 9, 9, 7, 5, 5, 9, 8, 5, 7, 8, 9, 7, 3, 7, 9, 6, 6, 6, 10, 9, 4, 5, 8, 8, 7, 5, 8, 10, 5, 5, 7, 8, 8, 5, 7, 10, 7, 5, 6, 7, 9, 5, 5, 9, 9, 7, 4, 5, 9, 8, 5, 7, 8, 8, 6, 4, 9, 8, 6, 6, 7, 10, 8, 4, 7, 9, 7, 6, 5, 9, 10, 5, 5, 7, 8, 8, 5, 7, 10, 6, 6, 6, 9, 9, 4, 5, 9, 9, 7, 5, 7, 10, 6, 5, 7, 8, 9, 5, 6, 9, 8
Sample_29End:

Sample_30:
.db 7, 6, 4, 5, 7, 8, 6, 9, 8, 5, 3, 6, 9, 9, 9, 10, 6, 5, 7, 9, 7, 6, 5, 8, 6, 10, 12, 8, 4, 3, 7, 8, 8, 8, 10, 5, 5, 9, 9, 7, 2, 5, 8, 7, 10, 10, 9, 4, 4, 10, 10, 6, 6, 7, 6, 6, 8, 12, 7, 2, 5, 8, 10, 7, 8, 8, 3, 3, 9, 11, 8, 4, 5, 8, 7, 9, 11, 7, 3, 2, 8, 11, 8, 8, 8, 6, 4, 7, 10, 8, 3, 6, 8, 8, 7, 6, 7, 4, 3, 9, 10, 8, 5, 6, 8, 6, 7, 10, 8, 4, 5, 9, 11, 7, 6, 7, 4, 5, 8, 11, 8, 3, 5, 8, 8, 7, 8, 8, 5, 4, 9, 11, 7, 5, 4, 7, 6, 7, 11, 8, 5, 5, 8, 9, 6, 6, 7, 6, 6, 9, 11, 9, 4, 4, 8, 6, 8, 7, 8, 5, 5, 9, 11, 7, 5, 6, 7, 7, 7, 11, 8, 3, 5, 8, 9, 8, 6, 8, 6, 5, 8, 11, 7, 4, 4, 8, 8, 7, 10, 7, 6, 4, 8, 10, 7, 5, 7, 7, 7, 8, 10, 8, 4, 5, 9, 9, 8, 6, 7, 6, 4, 9, 10, 8, 4, 5, 8, 8, 7, 9, 8, 4, 5, 7, 11, 7, 5, 7, 7, 7, 8, 10, 8, 3, 4, 8, 8, 7, 7, 8, 7, 5, 8, 10, 6, 5, 5, 8, 8, 8, 9, 8, 4, 5, 8, 9, 7, 4, 7, 7, 6, 8, 9, 8, 4, 4, 9, 8, 8, 7, 7, 5, 5, 8, 10, 7, 4, 6, 7, 8, 7, 9, 8, 4, 4, 8, 9, 7, 5, 7, 7, 6, 8, 9, 8, 4, 4, 8, 8, 6, 8, 7, 7, 5, 8, 10, 7, 4, 6, 7, 7, 8, 8, 9, 4, 5, 8, 9, 7, 6, 6, 7, 6, 8, 9, 7, 5, 4, 8, 9, 7, 8, 8, 5, 5, 7, 10, 7, 4, 6, 8, 8, 8, 9, 8
Sample_30End:

Sample_31:
.db 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 5, 6, 8, 7, 7, 8, 7, 4, 9, 6, 7, 6, 6, 3, 8, 6, 5, 10, 6, 7, 9, 4, 7, 7, 8, 7, 5, 11, 5, 6, 7, 5, 8, 8, 8, 9, 9, 5, 8, 6, 9, 9, 8, 8, 8, 5, 7, 8, 8, 7, 7, 7, 7, 8, 6, 10, 5, 9, 5, 7, 8, 5, 9, 6, 6, 8, 7, 5, 8, 6, 8, 6, 6, 7, 9, 7, 7, 9, 4, 8, 7, 6, 6, 9, 6, 9, 7, 5, 9, 5, 6, 10, 7, 6, 7, 6, 6, 9, 5, 8, 9, 5, 7, 8, 7, 6, 9, 7, 6, 9, 6, 5, 8, 8, 6, 8, 6, 6, 8, 6, 7, 7, 7, 11, 6, 8, 8, 7, 6, 8, 6, 6, 9, 6, 6, 8, 6, 6, 8, 5, 7, 8, 6, 8, 9, 5, 8, 7, 6, 8, 7, 7, 8, 6, 7, 8, 5, 7, 8, 6, 8, 8, 6, 7, 8, 5, 8, 7, 8, 7, 8, 8, 6, 8, 6, 6, 9, 5, 6, 8, 6, 7, 8, 5, 7, 9, 6, 6, 8, 7, 5, 9, 6, 6, 8, 7, 7, 8, 6, 7, 7, 7, 7, 7, 6, 8, 6, 6, 8, 7, 7, 8, 7, 6, 8, 5, 7, 8, 7, 6, 8, 6, 7, 8, 7, 7, 7, 7, 7, 7, 7, 5, 8, 7, 7, 7, 6, 7, 6, 8, 7, 7, 7, 7, 7, 7, 7, 6, 7, 7, 7, 7, 7, 7, 7, 7, 6, 7, 7, 7, 7, 7, 7, 6, 8, 7, 6, 10, 7, 6, 8, 6, 6, 10, 6, 7, 8, 7, 7, 7, 6, 7, 8, 7, 7, 7, 7, 5, 7, 7, 9, 8, 6, 8, 6, 7, 6, 7, 8, 7, 8, 7, 7, 7, 7, 6, 8, 6, 7, 9, 7, 6, 8, 7, 4, 8, 6, 7, 7, 7, 6, 9, 7, 6, 9, 6, 7, 8, 6, 7, 7, 7, 6, 7, 6, 6, 8, 5, 6, 9, 7, 8, 8, 6, 8, 6, 7, 7, 7, 8, 7, 7, 7, 7, 7, 6, 7, 7, 7, 7, 7, 7, 7, 7, 7, 8, 6, 7, 7, 7, 7, 7, 7, 7, 7, 6, 8, 7, 7, 7, 6, 6, 8, 6, 8, 7, 6, 7, 7, 7, 7, 7, 6, 7, 7, 7, 8, 7, 7, 6, 7, 8, 7, 8, 7, 7, 7, 6, 8, 8, 7, 7, 7, 7, 7, 7, 6, 8, 8, 6, 8, 8, 6, 7, 7, 7, 7, 7, 7, 6, 7, 7, 6, 8, 8, 6, 8, 6, 7, 7, 7, 7, 8, 7, 7, 7, 7, 6, 8, 7, 7, 8, 7, 6, 8, 6, 7, 8, 7, 7, 7, 7, 6, 7, 7, 7, 7, 7, 7, 7, 7, 7, 6, 7, 7, 7, 7, 7, 6, 7, 7, 7, 8, 7, 7, 7, 7
Sample_31End:

Sample_32:
.db 6, 4, 8, 5, 3, 6, 8, 4, 7, 8, 5, 8, 11, 10, 9, 8, 9, 7, 6, 9, 9, 6, 8, 8, 6, 9, 6, 5, 7, 9, 7, 5, 6, 5, 5, 3, 6, 7, 6, 3, 4, 8, 8, 7, 9, 11, 8, 5, 9, 10, 7, 6, 8, 7, 5, 6, 8, 8, 6, 7, 9, 5, 5, 6, 4, 3, 5, 5, 5, 5, 8, 8, 8, 10, 10, 9, 10, 10, 9, 8, 7, 6, 6, 8, 8, 8, 8, 9, 8, 8, 8, 8, 7, 6, 4, 4, 4, 3, 3, 4, 5, 5, 6, 8, 9, 9, 10, 10, 10, 9, 9, 8, 8, 7, 7, 7, 7, 7, 7, 8, 8, 8, 8, 7, 7, 6, 5, 5, 5, 5, 4, 5, 5, 6, 7, 8, 8, 8, 9, 8, 8, 8, 8, 8, 7, 7, 8, 8, 8, 8, 8, 8, 8, 8, 7, 6, 5, 5, 4, 4, 4, 5, 5, 6, 7, 7, 8, 9, 9, 9, 9, 9, 8, 8, 8, 7, 7, 7, 8, 8, 8, 8, 9, 8, 8, 7, 7, 6, 5, 5, 5, 4, 4, 5, 5, 5, 6, 7, 7, 7, 8, 8, 7, 7, 7, 7, 7, 7, 8, 8, 8, 8, 8, 8, 8, 8, 8, 7, 6, 6, 5, 5, 5, 5, 5, 6, 6, 7, 7, 7, 8, 8, 8, 8, 8, 8, 7, 7, 8, 8, 8, 8, 8, 9, 9, 9, 8, 8, 7, 6, 6, 5, 5, 5, 5, 5, 5, 6, 6, 7, 7, 7, 7, 7, 7, 7, 7, 7, 8, 7, 8, 8, 9, 8, 9, 9, 8, 8, 8, 7, 7, 6, 6, 5, 5, 5, 5, 5, 6, 6, 6, 6, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 8, 8, 8, 8, 9, 9, 8, 8, 7, 7, 7, 6, 6, 6, 6, 6, 6, 6, 6, 6, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 8, 8, 8, 9, 9, 9, 9, 8, 8, 8
Sample_32End:




VdpData:
.db $04,$80,$84,$81,$ff,$82,$ff,$85,$ff,$86,$ff,$87,$00,$88,$00,$89,$ff,$8a
VdpDataEnd:

Message:
.dw 1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1
.dw 1,1,1,1,1,1,20+32,18+32,7+32,$00,2+32,25+32,$00,12+32,9+32,20+32,20+32,12+32,5+32,19+32,3+32,1+32,12+32,5+32,1,1,1,1,1,1,1,1
.dw 1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1
.dw 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
.dw 0,0,0,0,0,0,13,13,19+32,1+32,13+32,16+32,12+32,9+32,14+32,7+32,0,18+32,1+32,20+32,5+32,0,$10,$10,0,0,0,0,0,0,0,0
.dw 0,0,0,0,0,0,13,13,19+32,1+32,13+32,16+32,12+32,5+32,$00,2+32,1+32,14+32,11+32,0,0,0,$10,$10
MessageEnd:


FontData:
.db $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00  ;00
.db $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00

.db $FF,$00,$00,$00,$FF,$00,$00,$00,$FF,$00,$00,$00,$FF,$00,$00,$00
.db $FF,$00,$00,$00,$FF,$00,$00,$00,$FF,$00,$00,$00,$FF,$00,$00,$00

.db $6C,$00,$00,$00,$6C,$00,$00,$00,$6C,$00,$00,$00,$00,$00,$00,$00
.db $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00

.db $36,$00,$00,$00,$36,$00,$00,$00,$7F,$00,$00,$00,$36,$00,$00,$00
.db $7F,$00,$00,$00,$36,$00,$00,$00,$36,$00,$00,$00,$00,$00,$00,$00

.db $0C,$00,$00,$00,$3F,$00,$00,$00,$68,$00,$00,$00,$3E,$00,$00,$00
.db $0B,$00,$00,$00,$7E,$00,$00,$00,$18,$00,$00,$00,$00,$00,$00,$00

.db $60,$00,$00,$00,$66,$00,$00,$00,$0C,$00,$00,$00,$18,$00,$00,$00
.db $30,$00,$00,$00,$66,$00,$00,$00,$06,$00,$00,$00,$00,$00,$00,$00

.db $38,$00,$00,$00,$6C,$00,$00,$00,$6C,$00,$00,$00,$38,$00,$00,$00
.db $6D,$00,$00,$00,$66,$00,$00,$00,$3B,$00,$00,$00,$00,$00,$00,$00

.db $0C,$00,$00,$00,$18,$00,$00,$00,$30,$00,$00,$00,$00,$00,$00,$00
.db $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00

.db $0C,$00,$00,$00,$18,$00,$00,$00,$30,$00,$00,$00,$30,$00,$00,$00
.db $30,$00,$00,$00,$18,$00,$00,$00,$0C,$00,$00,$00,$00,$00,$00,$00

.db $30,$00,$00,$00,$18,$00,$00,$00,$0C,$00,$00,$00,$0C,$00,$00,$00
.db $0C,$00,$00,$00,$18,$00,$00,$00,$30,$00,$00,$00,$00,$00,$00,$00

.db $00,$00,$00,$00,$18,$00,$00,$00,$7E,$00,$00,$00,$3C,$00,$00,$00  ;0a
.db $7E,$00,$00,$00,$18,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00

.db $00,$00,$00,$00,$18,$00,$00,$00,$18,$00,$00,$00,$7E,$00,$00,$00
.db $18,$00,$00,$00,$18,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00

.db $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
.db $00,$00,$00,$00,$18,$00,$00,$00,$18,$00,$00,$00,$30,$00,$00,$00

.db $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$7E,$00,$00,$00
.db $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00

.db $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
.db $00,$00,$00,$00,$18,$00,$00,$00,$18,$00,$00,$00,$00,$00,$00,$00

.db $00,$00,$00,$00,$06,$00,$00,$00,$0C,$00,$00,$00,$18,$00,$00,$00
.db $30,$00,$00,$00,$60,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00

.db $3C,$00,$00,$00,$66,$00,$00,$00,$6E,$00,$00,$00,$7E,$00,$00,$00  ;10
.db $76,$00,$00,$00,$66,$00,$00,$00,$3C,$00,$00,$00,$00,$00,$00,$00

.db $18,$00,$00,$00,$38,$00,$00,$00,$18,$00,$00,$00,$18,$00,$00,$00
.db $18,$00,$00,$00,$18,$00,$00,$00,$7E,$00,$00,$00,$00,$00,$00,$00

.db $3C,$00,$00,$00,$66,$00,$00,$00,$06,$00,$00,$00,$0C,$00,$00,$00
.db $18,$00,$00,$00,$30,$00,$00,$00,$7E,$00,$00,$00,$00,$00,$00,$00

.db $3C,$00,$00,$00,$66,$00,$00,$00,$06,$00,$00,$00,$1C,$00,$00,$00
.db $06,$00,$00,$00,$66,$00,$00,$00,$3C,$00,$00,$00,$00,$00,$00,$00

.db $0C,$00,$00,$00,$1C,$00,$00,$00,$3C,$00,$00,$00,$6C,$00,$00,$00
.db $7E,$00,$00,$00,$0C,$00,$00,$00,$0C,$00,$00,$00,$00,$00,$00,$00

.db $7E,$00,$00,$00,$60,$00,$00,$00,$7C,$00,$00,$00,$06,$00,$00,$00
.db $06,$00,$00,$00,$66,$00,$00,$00,$3C,$00,$00,$00,$00,$00,$00,$00

.db $1C,$00,$00,$00,$30,$00,$00,$00,$60,$00,$00,$00,$7C,$00,$00,$00
.db $66,$00,$00,$00,$66,$00,$00,$00,$3C,$00,$00,$00,$00,$00,$00,$00

.db $7E,$00,$00,$00,$06,$00,$00,$00,$0C,$00,$00,$00,$18,$00,$00,$00
.db $30,$00,$00,$00,$30,$00,$00,$00,$30,$00,$00,$00,$00,$00,$00,$00

.db $3C,$00,$00,$00,$66,$00,$00,$00,$66,$00,$00,$00,$3C,$00,$00,$00
.db $66,$00,$00,$00,$66,$00,$00,$00,$3C,$00,$00,$00,$00,$00,$00,$00

.db $3C,$00,$00,$00,$66,$00,$00,$00,$66,$00,$00,$00,$3E,$00,$00,$00
.db $06,$00,$00,$00,$0C,$00,$00,$00,$38,$00,$00,$00,$00,$00,$00,$00

.db $3C,$00,$00,$00,$66,$00,$00,$00,$66,$00,$00,$00,$7E,$00,$00,$00
.db $66,$00,$00,$00,$66,$00,$00,$00,$66,$00,$00,$00,$00,$00,$00,$00

.db $7C,$00,$00,$00,$66,$00,$00,$00,$66,$00,$00,$00,$7C,$00,$00,$00
.db $66,$00,$00,$00,$66,$00,$00,$00,$7C,$00,$00,$00,$00,$00,$00,$00

.db $3C,$00,$00,$00,$66,$00,$00,$00,$60,$00,$00,$00,$60,$00,$00,$00
.db $60,$00,$00,$00,$66,$00,$00,$00,$3C,$00,$00,$00,$00,$00,$00,$00

.db $78,$00,$00,$00,$6C,$00,$00,$00,$66,$00,$00,$00,$66,$00,$00,$00
.db $66,$00,$00,$00,$6C,$00,$00,$00,$78,$00,$00,$00,$00,$00,$00,$00

.db $7E,$00,$00,$00,$60,$00,$00,$00,$60,$00,$00,$00,$7C,$00,$00,$00
.db $60,$00,$00,$00,$60,$00,$00,$00,$7E,$00,$00,$00,$00,$00,$00,$00

.db $7E,$00,$00,$00,$60,$00,$00,$00,$60,$00,$00,$00,$7C,$00,$00,$00
.db $60,$00,$00,$00,$60,$00,$00,$00,$60,$00,$00,$00,$00,$00,$00,$00

.db $3C,$00,$00,$00,$66,$00,$00,$00,$6E,$00,$00,$00,$6A,$00,$00,$00    ;$20
.db $6E,$00,$00,$00,$60,$00,$00,$00,$3C,$00,$00,$00,$00,$00,$00,$00

.db $3C,$00,$00,$00,$66,$00,$00,$00,$66,$00,$00,$00,$7E,$00,$00,$00
.db $66,$00,$00,$00,$66,$00,$00,$00,$66,$00,$00,$00,$00,$00,$00,$00

.db $7C,$00,$00,$00,$66,$00,$00,$00,$66,$00,$00,$00,$7C,$00,$00,$00
.db $66,$00,$00,$00,$66,$00,$00,$00,$7C,$00,$00,$00,$00,$00,$00,$00

.db $3C,$00,$00,$00,$66,$00,$00,$00,$60,$00,$00,$00,$60,$00,$00,$00
.db $60,$00,$00,$00,$66,$00,$00,$00,$3C,$00,$00,$00,$00,$00,$00,$00

.db $78,$00,$00,$00,$6C,$00,$00,$00,$66,$00,$00,$00,$66,$00,$00,$00
.db $66,$00,$00,$00,$6C,$00,$00,$00,$78,$00,$00,$00,$00,$00,$00,$00

.db $7E,$00,$00,$00,$60,$00,$00,$00,$60,$00,$00,$00,$7C,$00,$00,$00
.db $60,$00,$00,$00,$60,$00,$00,$00,$7E,$00,$00,$00,$00,$00,$00,$00

.db $7E,$00,$00,$00,$60,$00,$00,$00,$60,$00,$00,$00,$7C,$00,$00,$00
.db $60,$00,$00,$00,$60,$00,$00,$00,$60,$00,$00,$00,$00,$00,$00,$00

.db $3C,$00,$00,$00,$66,$00,$00,$00,$60,$00,$00,$00,$6E,$00,$00,$00
.db $66,$00,$00,$00,$66,$00,$00,$00,$3C,$00,$00,$00,$00,$00,$00,$00

.db $66,$00,$00,$00,$66,$00,$00,$00,$66,$00,$00,$00,$7E,$00,$00,$00
.db $66,$00,$00,$00,$66,$00,$00,$00,$66,$00,$00,$00,$00,$00,$00,$00

.db $7E,$00,$00,$00,$18,$00,$00,$00,$18,$00,$00,$00,$18,$00,$00,$00
.db $18,$00,$00,$00,$18,$00,$00,$00,$7E,$00,$00,$00,$00,$00,$00,$00

.db $3E,$00,$00,$00,$0C,$00,$00,$00,$0C,$00,$00,$00,$0C,$00,$00,$00
.db $0C,$00,$00,$00,$6C,$00,$00,$00,$38,$00,$00,$00,$00,$00,$00,$00

.db $66,$00,$00,$00,$6C,$00,$00,$00,$78,$00,$00,$00,$70,$00,$00,$00
.db $78,$00,$00,$00,$6C,$00,$00,$00,$66,$00,$00,$00,$00,$00,$00,$00

.db $60,$00,$00,$00,$60,$00,$00,$00,$60,$00,$00,$00,$60,$00,$00,$00
.db $60,$00,$00,$00,$60,$00,$00,$00,$7E,$00,$00,$00,$00,$00,$00,$00

.db $63,$00,$00,$00,$77,$00,$00,$00,$7F,$00,$00,$00,$6B,$00,$00,$00
.db $6B,$00,$00,$00,$63,$00,$00,$00,$63,$00,$00,$00,$00,$00,$00,$00

.db $66,$00,$00,$00,$66,$00,$00,$00,$76,$00,$00,$00,$7E,$00,$00,$00
.db $6E,$00,$00,$00,$66,$00,$00,$00,$66,$00,$00,$00,$00,$00,$00,$00

.db $3C,$00,$00,$00,$66,$00,$00,$00,$66,$00,$00,$00,$66,$00,$00,$00
.db $66,$00,$00,$00,$66,$00,$00,$00,$3C,$00,$00,$00,$00,$00,$00,$00

.db $7C,$00,$00,$00,$66,$00,$00,$00,$66,$00,$00,$00,$7C,$00,$00,$00
.db $60,$00,$00,$00,$60,$00,$00,$00,$60,$00,$00,$00,$00,$00,$00,$00

.db $3C,$00,$00,$00,$66,$00,$00,$00,$66,$00,$00,$00,$66,$00,$00,$00
.db $6A,$00,$00,$00,$6C,$00,$00,$00,$36,$00,$00,$00,$00,$00,$00,$00

.db $7C,$00,$00,$00,$66,$00,$00,$00,$66,$00,$00,$00,$7C,$00,$00,$00
.db $6C,$00,$00,$00,$66,$00,$00,$00,$66,$00,$00,$00,$00,$00,$00,$00

.db $3C,$00,$00,$00,$66,$00,$00,$00,$60,$00,$00,$00,$3C,$00,$00,$00
.db $06,$00,$00,$00,$66,$00,$00,$00,$3C,$00,$00,$00,$00,$00,$00,$00

.db $7E,$00,$00,$00,$18,$00,$00,$00,$18,$00,$00,$00,$18,$00,$00,$00
.db $18,$00,$00,$00,$18,$00,$00,$00,$18,$00,$00,$00,$00,$00,$00,$00

.db $66,$00,$00,$00,$66,$00,$00,$00,$66,$00,$00,$00,$66,$00,$00,$00
.db $66,$00,$00,$00,$66,$00,$00,$00,$3C,$00,$00,$00,$00,$00,$00,$00

.db $66,$00,$00,$00,$66,$00,$00,$00,$66,$00,$00,$00,$66,$00,$00,$00
.db $66,$00,$00,$00,$3C,$00,$00,$00,$18,$00,$00,$00,$00,$00,$00,$00

.db $63,$00,$00,$00,$63,$00,$00,$00,$6B,$00,$00,$00,$6B,$00,$00,$00
.db $7F,$00,$00,$00,$77,$00,$00,$00,$63,$00,$00,$00,$00,$00,$00,$00

.db $66,$00,$00,$00,$66,$00,$00,$00,$3C,$00,$00,$00,$18,$00,$00,$00
.db $3C,$00,$00,$00,$66,$00,$00,$00,$66,$00,$00,$00,$00,$00,$00,$00

.db $66,$00,$00,$00,$66,$00,$00,$00,$66,$00,$00,$00,$3C,$00,$00,$00
.db $18,$00,$00,$00,$18,$00,$00,$00,$18,$00,$00,$00,$00,$00,$00,$00

.db $7E,$00,$00,$00,$06,$00,$00,$00,$0C,$00,$00,$00,$18,$00,$00,$00
.db $30,$00,$00,$00,$60,$00,$00,$00,$7E,$00,$00,$00,$00,$00,$00,$00

.db $7C,$00,$00,$00,$60,$00,$00,$00,$60,$00,$00,$00,$60,$00,$00,$00
.db $60,$00,$00,$00,$60,$00,$00,$00,$7C,$00,$00,$00,$00,$00,$00,$00

.db $00,$00,$00,$00,$60,$00,$00,$00,$30,$00,$00,$00,$18,$00,$00,$00
.db $0C,$00,$00,$00,$06,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00

.db $3E,$00,$00,$00,$06,$00,$00,$00,$06,$00,$00,$00,$06,$00,$00,$00
.db $06,$00,$00,$00,$06,$00,$00,$00,$3E,$00,$00,$00,$00,$00,$00,$00

.db $18,$00,$00,$00,$3C,$00,$00,$00,$66,$00,$00,$00,$42,$00,$00,$00
.db $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00

.db $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
.db $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$FF,$00,$00,$00

.db $1C,$00,$00,$00,$36,$00,$00,$00,$30,$00,$00,$00,$7C,$00,$00,$00
.db $30,$00,$00,$00,$30,$00,$00,$00,$7E,$00,$00,$00,$00,$00,$00,$00

.db $00,$00,$00,$00,$00,$00,$00,$00,$3C,$00,$00,$00,$06,$00,$00,$00
.db $3E,$00,$00,$00,$66,$00,$00,$00,$3E,$00,$00,$00,$00,$00,$00,$00

.db $60,$00,$00,$00,$60,$00,$00,$00,$7C,$00,$00,$00,$66,$00,$00,$00
.db $66,$00,$00,$00,$66,$00,$00,$00,$7C,$00,$00,$00,$00,$00,$00,$00

.db $00,$00,$00,$00,$00,$00,$00,$00,$3C,$00,$00,$00,$66,$00,$00,$00
.db $60,$00,$00,$00,$66,$00,$00,$00,$3C,$00,$00,$00,$00,$00,$00,$00

.db $06,$00,$00,$00,$06,$00,$00,$00,$3E,$00,$00,$00,$66,$00,$00,$00
.db $66,$00,$00,$00,$66,$00,$00,$00,$3E,$00,$00,$00,$00,$00,$00,$00

.db $00,$00,$00,$00,$00,$00,$00,$00,$3C,$00,$00,$00,$66,$00,$00,$00
.db $7E,$00,$00,$00,$60,$00,$00,$00,$3C,$00,$00,$00,$00,$00,$00,$00

.db $1C,$00,$00,$00,$30,$00,$00,$00,$30,$00,$00,$00,$7C,$00,$00,$00
.db $30,$00,$00,$00,$30,$00,$00,$00,$30,$00,$00,$00,$00,$00,$00,$00

.db $00,$00,$00,$00,$00,$00,$00,$00,$3E,$00,$00,$00,$66,$00,$00,$00
.db $66,$00,$00,$00,$3E,$00,$00,$00,$06,$00,$00,$00,$3C,$00,$00,$00

.db $60,$00,$00,$00,$60,$00,$00,$00,$7C,$00,$00,$00,$66,$00,$00,$00
.db $66,$00,$00,$00,$66,$00,$00,$00,$66,$00,$00,$00,$00,$00,$00,$00

.db $18,$00,$00,$00,$00,$00,$00,$00,$38,$00,$00,$00,$18,$00,$00,$00
.db $18,$00,$00,$00,$18,$00,$00,$00,$3C,$00,$00,$00,$00,$00,$00,$00

.db $18,$00,$00,$00,$00,$00,$00,$00,$38,$00,$00,$00,$18,$00,$00,$00
.db $18,$00,$00,$00,$18,$00,$00,$00,$18,$00,$00,$00,$70,$00,$00,$00

.db $60,$00,$00,$00,$60,$00,$00,$00,$66,$00,$00,$00,$6C,$00,$00,$00
.db $78,$00,$00,$00,$6C,$00,$00,$00,$66,$00,$00,$00,$00,$00,$00,$00

.db $38,$00,$00,$00,$18,$00,$00,$00,$18,$00,$00,$00,$18,$00,$00,$00
.db $18,$00,$00,$00,$18,$00,$00,$00,$3C,$00,$00,$00,$00,$00,$00,$00

.db $00,$00,$00,$00,$00,$00,$00,$00,$36,$00,$00,$00,$7F,$00,$00,$00
.db $6B,$00,$00,$00,$6B,$00,$00,$00,$63,$00,$00,$00,$00,$00,$00,$00

.db $00,$00,$00,$00,$00,$00,$00,$00,$7C,$00,$00,$00,$66,$00,$00,$00
.db $66,$00,$00,$00,$66,$00,$00,$00,$66,$00,$00,$00,$00,$00,$00,$00

.db $00,$00,$00,$00,$00,$00,$00,$00,$3C,$00,$00,$00,$66,$00,$00,$00
.db $66,$00,$00,$00,$66,$00,$00,$00,$3C,$00,$00,$00,$00,$00,$00,$00

.db $00,$00,$00,$00,$00,$00,$00,$00,$7C,$00,$00,$00,$66,$00,$00,$00
.db $66,$00,$00,$00,$7C,$00,$00,$00,$60,$00,$00,$00,$60,$00,$00,$00

.db $00,$00,$00,$00,$00,$00,$00,$00,$3E,$00,$00,$00,$66,$00,$00,$00
.db $66,$00,$00,$00,$3E,$00,$00,$00,$06,$00,$00,$00,$07,$00,$00,$00

.db $00,$00,$00,$00,$00,$00,$00,$00,$6C,$00,$00,$00,$76,$00,$00,$00
.db $60,$00,$00,$00,$60,$00,$00,$00,$60,$00,$00,$00,$00,$00,$00,$00

.db $00,$00,$00,$00,$00,$00,$00,$00,$3E,$00,$00,$00,$60,$00,$00,$00
.db $3C,$00,$00,$00,$06,$00,$00,$00,$7C,$00,$00,$00,$00,$00,$00,$00

.db $30,$00,$00,$00,$30,$00,$00,$00,$7C,$00,$00,$00,$30,$00,$00,$00
.db $30,$00,$00,$00,$30,$00,$00,$00,$1C,$00,$00,$00,$00,$00,$00,$00

.db $00,$00,$00,$00,$00,$00,$00,$00,$66,$00,$00,$00,$66,$00,$00,$00
.db $66,$00,$00,$00,$66,$00,$00,$00,$3E,$00,$00,$00,$00,$00,$00,$00

.db $00,$00,$00,$00,$00,$00,$00,$00,$66,$00,$00,$00,$66,$00,$00,$00
.db $66,$00,$00,$00,$3C,$00,$00,$00,$18,$00,$00,$00,$00,$00,$00,$00

.db $00,$00,$00,$00,$00,$00,$00,$00,$63,$00,$00,$00,$6B,$00,$00,$00
.db $6B,$00,$00,$00,$7F,$00,$00,$00,$36,$00,$00,$00,$00,$00,$00,$00

.db $00,$00,$00,$00,$00,$00,$00,$00,$66,$00,$00,$00,$3C,$00,$00,$00
.db $18,$00,$00,$00,$3C,$00,$00,$00,$66,$00,$00,$00,$00,$00,$00,$00

.db $00,$00,$00,$00,$00,$00,$00,$00,$66,$00,$00,$00,$66,$00,$00,$00
.db $66,$00,$00,$00,$3E,$00,$00,$00,$06,$00,$00,$00,$3C,$00,$00,$00

.db $00,$00,$00,$00,$00,$00,$00,$00,$7E,$00,$00,$00,$0C,$00,$00,$00
.db $18,$00,$00,$00,$30,$00,$00,$00,$7E,$00,$00,$00,$00,$00,$00,$00

.db $0C,$00,$00,$00,$18,$00,$00,$00,$18,$00,$00,$00,$70,$00,$00,$00
.db $18,$00,$00,$00,$18,$00,$00,$00,$0C,$00,$00,$00,$00,$00,$00,$00

.db $18,$00,$00,$00,$18,$00,$00,$00,$18,$00,$00,$00,$00,$00,$00,$00
.db $18,$00,$00,$00,$18,$00,$00,$00,$18,$00,$00,$00,$00,$00,$00,$00

.db $30,$00,$00,$00,$18,$00,$00,$00,$18,$00,$00,$00,$0E,$00,$00,$00
.db $18,$00,$00,$00,$18,$00,$00,$00,$30,$00,$00,$00,$00,$00,$00,$00

.db $31,$00,$00,$00,$6B,$00,$00,$00,$46,$00,$00,$00,$00,$00,$00,$00
.db $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
FontDataEnd:


PaletteData:
.db $00,$3f
PaletteDataEnd: